@@ -312,7 +312,7 @@ public class AkinPoints extends LaTeXDrawPolygon
 				add+=",shadowangle="+(float)Math.toDegrees(shadowAngle);//$NON-NLS-1$
 			
 			if(((float)shadowSize) != ((float)DEFAULT_SHADOW_SIZE))
-				add+=",shadowsize="+(float)(shadowSize/PPC);//$NON-NLS-1$
+				add+=",shadowsize="+LaTeXDrawNumber.getCutNumber((float)(shadowSize/PPC), threshold);//$NON-NLS-1$
 			
 			if(!shadowColor.equals(PSTricksConstants.DEFAULT_SHADOW_COLOR))
 			{
@@ -343,12 +343,12 @@ public class AkinPoints extends LaTeXDrawPolygon
 		
 		if(lineStyle.equals(PSTricksConstants.LINE_DOTTED_STYLE))
 			add += ",linestyle="+lineStyle+",dotsep="+ //$NON-NLS-1$ //$NON-NLS-2$
-			(dotSep/ppc)+ "cm";	//$NON-NLS-1$
+			LaTeXDrawNumber.getCutNumber(dotSep/ppc, threshold)+ "cm";	//$NON-NLS-1$
 		else
 			if(lineStyle.equals(PSTricksConstants.LINE_DASHED_STYLE))
 				add += ",linestyle="+lineStyle+",dash=" + //$NON-NLS-1$ //$NON-NLS-2$
-				(blackDashLength/ppc) + "cm "+ //$NON-NLS-1$
-				(whiteDashLength/ppc) + "cm";//$NON-NLS-1$
+				LaTeXDrawNumber.getCutNumber(blackDashLength/ppc, threshold) + "cm "+ //$NON-NLS-1$
+				LaTeXDrawNumber.getCutNumber(whiteDashLength/ppc, threshold) + "cm";//$NON-NLS-1$
 		
 		if(type==TYPE_CURVES)
 		{
@@ -448,7 +448,7 @@ public class AkinPoints extends LaTeXDrawPolygon
 			add += ",fillcolor=" + name; //$NON-NLS-1$
 		}
 		
-		return "\\pscustom[linewidth=" + (thickness/ppc)+ fillCode + add +"]\n{\n\\newpath\n" + //$NON-NLS-1$//$NON-NLS-2$
+		return "\\pscustom[linewidth=" + LaTeXDrawNumber.getCutNumber(thickness/ppc, threshold) + fillCode + add +"]\n{\n\\newpath\n" + //$NON-NLS-1$//$NON-NLS-2$
 				coord + (open ? "" : "\\closepath")+ (hasShadow ? "\\openshadow\n" : "") + '}';//$NON-NLS-1$//$NON-NLS-2$//$NON-NLS-3$//$NON-NLS-4$
 	}
 
