@@ -17,6 +17,7 @@ import latexDraw.ui.LaTeXDrawFrame;
 import latexDraw.ui.components.Delimitor;
 import latexDraw.ui.components.MagneticGrid;
 import latexDraw.ui.dialog.AbstractParametersFrame;
+import latexDraw.util.LaTeXDrawNumber;
 import latexDraw.util.LaTeXDrawPoint2D;
 
 
@@ -749,6 +750,7 @@ public class Arc extends Circle implements Arrowable
 		String add1 = "", add2="", startCode="", addEnd="", fillType="";  //$NON-NLS-1$  //$NON-NLS-2$  //$NON-NLS-3$  //$NON-NLS-4$  //$NON-NLS-5$
 		String arrowsCode="", endCode = ""; //$NON-NLS-1$//$NON-NLS-2$
 		boolean isFilledWasChanged = false;
+		double threshold = 0.001;
 		
 		if(hasShadow)
 		{
@@ -757,7 +759,7 @@ public class Arc extends Circle implements Arrowable
 				fillType+=",shadowangle="+(float)Math.toDegrees(shadowAngle);//$NON-NLS-1$
 			
 			if(((float)shadowSize) != ((float)DEFAULT_SHADOW_SIZE))
-				fillType+=",shadowsize="+(float)(shadowSize/PPC);//$NON-NLS-1$
+				fillType+=",shadowsize="+LaTeXDrawNumber.getCutNumber((float)(shadowSize/PPC), threshold) ;//$NON-NLS-1$
 			
 			if(!shadowColor.equals(PSTricksConstants.DEFAULT_SHADOW_COLOR))
 			{
@@ -853,14 +855,14 @@ public class Arc extends Circle implements Arrowable
 			startCode = "\\pswedge"; //$NON-NLS-1$
 		else
 		{
-			endCode = "\n\\psline[linewidth=" + (thickness/ppc) +add1+ //$NON-NLS-1$
-			"](" +(float)((x+Math.cos(startAngle)*radius)/ppc)+ ',' + //$NON-NLS-1$
-			(float)((y+Math.sin(startAngle)*radius)/ppc)+
-			")(" +(float)((x+Math.cos(endAngle)*radius)/ppc)+ ','; //$NON-NLS-1$
+			endCode = "\n\\psline[linewidth=" + LaTeXDrawNumber.getCutNumber(thickness/ppc, threshold) +add1+ //$NON-NLS-1$
+			"](" +LaTeXDrawNumber.getCutNumber((float)((x+Math.cos(startAngle)*radius)/ppc), threshold)+ ',' + //$NON-NLS-1$
+			LaTeXDrawNumber.getCutNumber((float)((y+Math.sin(startAngle)*radius)/ppc), threshold)+
+			")(" +LaTeXDrawNumber.getCutNumber((float)((x+Math.cos(endAngle)*radius)/ppc), threshold)+ ','; //$NON-NLS-1$
 			
 			if(endAngle%Math.PI==0)
-				endCode +=(float)(y/ppc)+ ")"; //$NON-NLS-1$
-			else endCode +=(float)((y+Math.sin(endAngle)*radius)/ppc)+ ")"; //$NON-NLS-1$
+				endCode +=LaTeXDrawNumber.getCutNumber((float)(y/ppc), threshold)+ ")"; //$NON-NLS-1$
+			else endCode +=LaTeXDrawNumber.getCutNumber((float)((y+Math.sin(endAngle)*radius)/ppc), threshold)+ ")"; //$NON-NLS-1$
 			startCode = "\\psarc";//$NON-NLS-1$
 		}
 		
@@ -878,7 +880,7 @@ public class Arc extends Circle implements Arrowable
 			if(Math.abs(y2) < 0.001) y2 = 0;
 			
 			startCode ="\\rput{"+(float)angle+ "}("+ //$NON-NLS-1$ //$NON-NLS-2$
-			(float)x2+','+(float)y2+"){"+startCode; //$NON-NLS-1$
+			LaTeXDrawNumber.getCutNumber((float)x2, threshold)+','+LaTeXDrawNumber.getCutNumber((float)y2, threshold)+"){"+startCode; //$NON-NLS-1$
 			addEnd = "}"; //$NON-NLS-1$
 		}		
 		
@@ -887,7 +889,7 @@ public class Arc extends Circle implements Arrowable
 		
 		if(hasDoubleBoundary)
 		{
-			add1+=",doubleline=true,doublesep="+(float)(doubleSep/ppc); //$NON-NLS-1$
+			add1+=",doubleline=true,doublesep="+LaTeXDrawNumber.getCutNumber((float)(doubleSep/ppc), threshold); //$NON-NLS-1$
 			add1+=",dimen="+bordersPosition;  //$NON-NLS-1$
 			
 			if(doubleColor!=PSTricksConstants.DEFAULT_DOUBLE_COLOR)
@@ -913,17 +915,14 @@ public class Arc extends Circle implements Arrowable
 			add1 += ",fillcolor=" + name; //$NON-NLS-1$
 		}
 		
-		if(Math.abs(x) < 0.001) x = 0;
-		if(Math.abs(y) < 0.001) y = 0;
-		if(Math.abs(radius) < 0.001) radius = 0;
 		if(isFilledWasChanged) isFilled = false;
 		
-		return startCode+ "[linewidth=" + (thickness/ppc) + //$NON-NLS-1$
-				add1 + add2 + fillType + "]"+ arrowsCode + "(" + (float)(x/ppc)+','+ //$NON-NLS-1$ //$NON-NLS-2$
-						(float)(y/ppc) + "){"+ //$NON-NLS-1$
-						(float)(radius/ppc) +"}{"+ //$NON-NLS-1$
-						(float)Math.toDegrees(startAngle)
-				 +"}{"+(float)Math.toDegrees(endAngle)+'}'+endCode+ addEnd; //$NON-NLS-1$
+		return startCode+ "[linewidth=" + LaTeXDrawNumber.getCutNumber(thickness/ppc, threshold) + //$NON-NLS-1$
+				add1 + add2 + fillType + "]"+ arrowsCode + "(" + LaTeXDrawNumber.getCutNumber((float)(x/ppc), threshold)+','+ //$NON-NLS-1$ //$NON-NLS-2$
+				LaTeXDrawNumber.getCutNumber((float)(y/ppc), threshold) + "){"+ //$NON-NLS-1$
+				LaTeXDrawNumber.getCutNumber((float)(radius/ppc), threshold) +"}{"+ //$NON-NLS-1$
+				LaTeXDrawNumber.getCutNumber((float)Math.toDegrees(startAngle), threshold)
+				 +"}{"+LaTeXDrawNumber.getCutNumber((float)Math.toDegrees(endAngle), threshold)+'}'+endCode+ addEnd; //$NON-NLS-1$
 	}
 
 	
