@@ -19,6 +19,7 @@ import javax.swing.JLabel;
 import latexDraw.psTricks.PSTricksConstants;
 import latexDraw.ui.components.LaTeXDrawComboBox;
 import latexDraw.ui.components.LabelListCellRenderer;
+import latexDraw.util.LaTeXDrawNumber;
 import latexDraw.util.LaTeXDrawPoint2D;
 import latexDraw.util.LaTeXDrawResources;
 
@@ -649,6 +650,8 @@ public class ArrowHead implements Serializable, Cloneable
 	
 	public String getParametersCode()
 	{
+		double threshold = 0.001;
+		
 		if(currentArrowStyle.equals(PSTricksConstants.BARIN_STYLE) ||
 		   currentArrowStyle.equals(PSTricksConstants.BAREND_STYLE) ||
 		   currentArrowStyle.equals(PSTricksConstants.LSBRACKET_STYLE) ||
@@ -656,7 +659,7 @@ public class ArrowHead implements Serializable, Cloneable
 		   currentArrowStyle.equals(PSTricksConstants.LRBRACKET_STYLE) ||
 		   currentArrowStyle.equals(PSTricksConstants.RRBRACKET_STYLE))
 		{
-			String code = "tbarsize="+(float)(getTBarSizeDim()/Figure.PPC)+"cm " +(float)getTBarSizeNum(); //$NON-NLS-1$ //$NON-NLS-2$
+			String code = "tbarsize="+LaTeXDrawNumber.getCutNumber((float)(getTBarSizeDim()/Figure.PPC), threshold)+"cm " +(float)getTBarSizeNum(); //$NON-NLS-1$ //$NON-NLS-2$
 			if(currentArrowStyle.equals(PSTricksConstants.LSBRACKET_STYLE) ||
 			   currentArrowStyle.equals(PSTricksConstants.RSBRACKET_STYLE))
 				code+=",bracketlength="+(float)getBracketNum(); //$NON-NLS-1$
@@ -672,7 +675,7 @@ public class ArrowHead implements Serializable, Cloneable
 				currentArrowStyle.equals(PSTricksConstants.RARROW_STYLE) ||
 				currentArrowStyle.equals(PSTricksConstants.DLARROW_STYLE) ||
 				currentArrowStyle.equals(PSTricksConstants.DRARROW_STYLE))
-			return "arrowsize="+(float)(getArrowSizeDim()/Figure.PPC) +"cm " +//$NON-NLS-1$ //$NON-NLS-2$
+			return "arrowsize="+LaTeXDrawNumber.getCutNumber((float)(getArrowSizeDim()/Figure.PPC), threshold) +"cm " +//$NON-NLS-1$ //$NON-NLS-2$
 				(float)getArrowSizeNum()+",arrowlength="+   //$NON-NLS-1$
 				(float)getArrowLength()+",arrowinset="+(float)getArrowInset(); //$NON-NLS-1$
 		
@@ -680,7 +683,7 @@ public class ArrowHead implements Serializable, Cloneable
 			currentArrowStyle.equals(PSTricksConstants.DISKIN_STYLE) ||
 			currentArrowStyle.equals(PSTricksConstants.CIRCLEEND_STYLE) || 
 			currentArrowStyle.equals(PSTricksConstants.DISKEND_STYLE))
-			return "dotsize="+(float)(getDotSizeDim()/Figure.PPC)+"cm "+(float)getDotSizeNum(); //$NON-NLS-1$ //$NON-NLS-2$
+			return "dotsize="+LaTeXDrawNumber.getCutNumber((float)(getDotSizeDim()/Figure.PPC), threshold)+"cm "+(float)getDotSizeNum(); //$NON-NLS-1$ //$NON-NLS-2$
 		
 		return "";//$NON-NLS-1$
 	}
