@@ -13,6 +13,7 @@ import latexDraw.lang.LaTeXDrawLang;
 import latexDraw.psTricks.PSTricksConstants;
 import latexDraw.ui.components.LaTeXDrawComboBox;
 import latexDraw.ui.components.MagneticGrid;
+import latexDraw.util.LaTeXDrawNumber;
 import latexDraw.util.LaTeXDrawPoint2D;
 
 
@@ -734,7 +735,8 @@ public class Axe extends GridShape implements Arrowable
 		String start = "", end = "", arrowsCode = "";//$NON-NLS-1$//$NON-NLS-2$//$NON-NLS-3$
 		String arrowHead1Style = arrowHead1.getArrowStyle(), add = "";//$NON-NLS-1$
 		String arrowHead2Style = arrowHead2.getArrowStyle();
-
+		double threshold = 0.001;
+		
 		if(isXLabelSouth)
 		{
 			startY = gridStart.y;
@@ -768,8 +770,8 @@ public class Axe extends GridShape implements Arrowable
 			if(Math.abs(position.x) < 0.001) posY = 0;
 			
 			end +="}"; //$NON-NLS-1$
-			start = "\\rput(" + (float)((posX-d.x)/ppc) + "," + //$NON-NLS-1$ //$NON-NLS-2$
-					(float)((d.y-posY)/ppc) + "){" + start; //$NON-NLS-1$
+			start = "\\rput(" + LaTeXDrawNumber.getCutNumber((float)((posX-d.x)/ppc), threshold) + "," + //$NON-NLS-1$ //$NON-NLS-2$
+					LaTeXDrawNumber.getCutNumber((float)((d.y-posY)/ppc), threshold) + "){" + start; //$NON-NLS-1$
 		}
 		
 		if(rotationAngle % (Math.PI*2) != 0.)
@@ -782,10 +784,7 @@ public class Axe extends GridShape implements Arrowable
 			x = -Math.cos(-rotationAngle) * cx + Math.sin(-rotationAngle) * cy + cx;
 			y = -Math.sin(-rotationAngle) * cx - Math.cos(-rotationAngle) * cy + cy;
 
-			if(Math.abs(x) < 0.001) x = 0;
-			if(Math.abs(y) < 0.001) y = 0;
-			
-			start = start+"\\rput{" + (float)angle + "}(" + (float)x + ',' + (float)y + "){"; //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
+			start = start+"\\rput{" + (float)angle + "}(" + LaTeXDrawNumber.getCutNumber((float)x, threshold) + ',' + LaTeXDrawNumber.getCutNumber((float)y, threshold) + "){"; //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
 			end = end+"}"; //$NON-NLS-1$
 		}
 		
@@ -865,7 +864,7 @@ public class Axe extends GridShape implements Arrowable
 			add+=",ticks="+getTicksDisplayedToken();//$NON-NLS-1$
 		
 		if(((float)ticksSize/ppc)!=((float)PSTricksConstants.DEFAULT_TICKS_SIZE))
-			add+=",ticksize="+(float)(ticksSize/ppc)+"cm";//$NON-NLS-1$//$NON-NLS-2$
+			add+=",ticksize="+LaTeXDrawNumber.getCutNumber((float)(ticksSize/ppc), threshold)+"cm";//$NON-NLS-1$//$NON-NLS-2$
 			
 		if(distLabels.x!=0.)
 			add+=",dx="+(float)distLabels.x+"cm";//$NON-NLS-1$//$NON-NLS-2$
@@ -890,7 +889,7 @@ public class Axe extends GridShape implements Arrowable
 		if(showOrigin!=PSTricksConstants.DEFAULT_SHOW_ORIGIN)
 			add+=",showorigin="+showOrigin;//$NON-NLS-1$
 		
-		return start +"\\psaxes[linewidth="+ (thickness/ppc) + //$NON-NLS-1$ 
+		return start +"\\psaxes[linewidth="+ LaTeXDrawNumber.getCutNumber((thickness/ppc), threshold) + //$NON-NLS-1$ 
 				add + "]" + arrowsCode + coord + end;//$NON-NLS-1$
 	}
 
