@@ -4,6 +4,7 @@ import java.awt.*;
 import java.awt.geom.AffineTransform;
 import java.awt.geom.GeneralPath;
 import java.awt.geom.Line2D;
+import java.awt.geom.Path2D;
 import java.awt.geom.Rectangle2D;
 import java.io.IOException;
 import java.io.ObjectInputStream;
@@ -866,7 +867,7 @@ public class BezierCurve extends LaTeXDrawPolygon implements Arrowable
 			return null;
 		
 		int size = pts.size(), i;
-		GeneralPath gp = new GeneralPath(GeneralPath.WIND_EVEN_ODD);
+		GeneralPath gp = new GeneralPath(Path2D.WIND_EVEN_ODD);
 		LaTeXDrawPoint2D ctrl1;
 		
 		//JAVA6 : put in moveto(double, double,...)
