@@ -605,7 +605,7 @@ public class Draw extends Figure
 	
 	
 	@Override
-	public void onRelease() 
+	public synchronized void onRelease() 
 	{
 		super.onRelease();		
 		
@@ -618,7 +618,7 @@ public class Draw extends Figure
 	
 	
 	@Override
-	public void onDelimitorRelease()
+	public synchronized void onDelimitorRelease()
 	{
 		super.onDelimitorRelease();	
 		
@@ -735,7 +735,7 @@ public class Draw extends Figure
 
 
 	@Override
-	public void updateGravityCenter() 
+	public synchronized void updateGravityCenter() 
 	{
 		LaTeXDrawPoint2D nw = new LaTeXDrawPoint2D(Double.MAX_VALUE, Double.MAX_VALUE);
 		LaTeXDrawPoint2D se = new LaTeXDrawPoint2D(Double.MIN_VALUE, Double.MIN_VALUE);
