@@ -11,6 +11,7 @@ import latexDraw.psTricks.DviPsColors;
 import latexDraw.psTricks.PSTricksConstants;
 import latexDraw.ui.LaTeXDrawFrame;
 import latexDraw.ui.components.MagneticGrid;
+import latexDraw.util.LaTeXDrawNumber;
 import latexDraw.util.LaTeXDrawPoint2D;
 
 
@@ -417,6 +418,7 @@ public class Ellipse extends Figure implements BordersMovable, DoubleBoundaryabl
 		double width  = Math.abs(pt1.x-pt2.x);
 		double height = Math.abs(pt1.y-pt3.y);
 		boolean isFilledWasChanged = false;
+		double threshold = 0.001;
 		
 		if(hasShadow)
 		{
@@ -425,7 +427,7 @@ public class Ellipse extends Figure implements BordersMovable, DoubleBoundaryabl
 				fillType+=",shadowangle="+(float)Math.toDegrees(shadowAngle);//$NON-NLS-1$
 			
 			if(((float)shadowSize)!=((float)DEFAULT_SHADOW_SIZE))
-				fillType+=",shadowsize="+(float)(shadowSize/PPC);//$NON-NLS-1$
+				fillType+=",shadowsize="+LaTeXDrawNumber.getCutNumber((float)(shadowSize/PPC),threshold);//$NON-NLS-1$
 			
 			if(!shadowColor.equals(PSTricksConstants.DEFAULT_SHADOW_COLOR))
 			{
@@ -460,10 +462,7 @@ public class Ellipse extends Figure implements BordersMovable, DoubleBoundaryabl
 			double y2 =  -Math.sin(-rotationAngle)*cx-
 						Math.cos(-rotationAngle)*cy+cy;
 
-			if(Math.abs(x2) < 0.001) x2 = 0;
-			if(Math.abs(y2) < 0.001) y2 = 0;
-			
-			addBegin +="\\rput{"+(float)angle+ "}("+(float)x2+','+(float)y2+"){"; //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
+			addBegin +="\\rput{"+(float)angle+ "}("+LaTeXDrawNumber.getCutNumber((float)x2,threshold)+','+LaTeXDrawNumber.getCutNumber((float)y2,threshold)+"){"; //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
 			addEnd = "}"; //$NON-NLS-1$
 		}
 		
@@ -471,7 +470,7 @@ public class Ellipse extends Figure implements BordersMovable, DoubleBoundaryabl
 		
 		if(hasDoubleBoundary)
 		{
-			add+=",doubleline=true,doublesep="+(float)(doubleSep/ppc); //$NON-NLS-1$
+			add+=",doubleline=true,doublesep="+LaTeXDrawNumber.getCutNumber((float)(doubleSep/ppc),threshold); //$NON-NLS-1$
 			
 			if(doubleColor!=PSTricksConstants.DEFAULT_DOUBLE_COLOR)
 			{
@@ -485,13 +484,11 @@ public class Ellipse extends Figure implements BordersMovable, DoubleBoundaryabl
 			}
 		}
 		
-		if(Math.abs(x) < 0.001) x = 0;
-		if(Math.abs(y) < 0.001) y = 0;
 		if(isFilledWasChanged) isFilled = false;
 		
 		return addBegin+"\\psellipse[linewidth=" + (thickness/ppc) +  //$NON-NLS-1$
-			add + fillType + "](" + (float)(x/ppc) + ',' + (float)(y/ppc) + ")("  //$NON-NLS-1$ //$NON-NLS-2$
-				+ (float)((width/2.)/ppc) + ',' + (float)((height/2.)/ppc) + ')'+addEnd;
+			add + fillType + "](" + LaTeXDrawNumber.getCutNumber((float)(x/ppc),threshold) + ',' + LaTeXDrawNumber.getCutNumber((float)(y/ppc),threshold) + ")("  //$NON-NLS-1$ //$NON-NLS-2$
+				+ LaTeXDrawNumber.getCutNumber((float)((width/2.)/ppc),threshold) + ',' + LaTeXDrawNumber.getCutNumber((float)((height/2.)/ppc),threshold) + ')'+addEnd;
 	}
 
 
