@@ -7,6 +7,7 @@ import static java.lang.Math.toDegrees;
 import java.awt.*;
 import java.awt.geom.GeneralPath;
 import java.awt.geom.Line2D;
+import java.awt.geom.Path2D;
 import java.awt.geom.Point2D;
 import java.awt.geom.Rectangle2D;
 import java.io.Serializable;
@@ -810,7 +811,7 @@ public abstract class Figure implements Serializable, Cloneable, Drawable
 	 * Allows to set the last point of the figure
 	 * @param pt The new point
 	 */
-	public synchronized void setLastPoint(LaTeXDrawPoint2D pt)
+	public void setLastPoint(LaTeXDrawPoint2D pt)
 	{
 		setLastPoint(pt.x, pt.y);
 	}
@@ -838,7 +839,7 @@ public abstract class Figure implements Serializable, Cloneable, Drawable
 	 * Allows to set the first point of the figure
 	 * @param pt The new point
 	 */
-	public synchronized void setFirstPoint(LaTeXDrawPoint2D pt)
+	public void setFirstPoint(LaTeXDrawPoint2D pt)
 	{
 		setFirstPoint(pt.x, pt.y);
 	}
@@ -1116,7 +1117,7 @@ public abstract class Figure implements Serializable, Cloneable, Drawable
 	{
 		Color formerColor = g.getColor();
 		GeneralPath p = new GeneralPath(s);
-		p.setWindingRule(GeneralPath.WIND_NON_ZERO);
+		p.setWindingRule(Path2D.WIND_NON_ZERO);
 		
 		try
 		{
@@ -1548,7 +1549,7 @@ public abstract class Figure implements Serializable, Cloneable, Drawable
 	 * Allows to get the south-east point by taking into account the angle of rotation.
 	 * @return The south-east point of the rotated rectangle.
 	 */
-	public synchronized LaTeXDrawPoint2D getTheSERotatedPoint()
+	public LaTeXDrawPoint2D getTheSERotatedPoint()
 	{
 		if(borders != null)
 			return borders.getTheSERotatedPoint();
@@ -1680,7 +1681,7 @@ public abstract class Figure implements Serializable, Cloneable, Drawable
 	 * Corresponds to what to do when the user click on the figure.
 	 * @param pt The clicked point.
 	 */
-	public synchronized void onClick(Point pt)
+	public void onClick(Point pt)
 	{
 		isSelected = true;
 
@@ -1710,7 +1711,7 @@ public abstract class Figure implements Serializable, Cloneable, Drawable
 	 * Allows to obtain the point most to the South and on the East of the figure.
 	 * @return the point most to the South and on the East of the figure.
 	 */
-	public synchronized LaTeXDrawPoint2D getTheSEPoint()
+	public LaTeXDrawPoint2D getTheSEPoint()
 	{
 		if(borders != null)
 			return borders.getTheSEPoint();
@@ -2610,7 +2611,7 @@ public abstract class Figure implements Serializable, Cloneable, Drawable
 	/**
 	 * @return the canHaveArrow.
 	 */
-	public synchronized boolean canHaveArrow()
+	public boolean canHaveArrow()
 	{
 		return canHaveArrow;
 	}
