@@ -11,6 +11,7 @@ import java.util.Vector;
 
 import latexDraw.figures.Text.TextPosition;
 import latexDraw.psTricks.PSTricksConstants;
+import latexDraw.util.LaTeXDrawNumber;
 import latexDraw.util.LaTeXDrawPoint2D;
 
 
@@ -546,7 +547,7 @@ public class FramedBox implements Cloneable, Serializable
 
 		if(((float)(frameSep/ppc))!=(float)PSTricksConstants.DEFAULT_FRAME_SEP)
 			boxParams += (boxParams.length()>0 ? "," : "")//$NON-NLS-1$//$NON-NLS-2$
-					+"framesep="+(float)frameSep/ppc;//$NON-NLS-1$
+					+"framesep="+LaTeXDrawNumber.getCutNumber((float)frameSep/ppc,0.0001);//$NON-NLS-1$
 
 		if(boxSep!=PSTricksConstants.DEFAULT_BOX_SEP)
 			boxParams += (boxParams.length()>0 ? "," : "")+"boxsep=" //$NON-NLS-1$ //$NON-NLS-2$//$NON-NLS-3$
