@@ -10,6 +10,7 @@ import latexDraw.psTricks.DviPsColors;
 import latexDraw.psTricks.PSTricksConstants;
 import latexDraw.ui.LaTeXDrawFrame;
 import latexDraw.ui.components.MagneticGrid;
+import latexDraw.util.LaTeXDrawNumber;
 import latexDraw.util.LaTeXDrawPoint2D;
 
 
@@ -590,8 +591,8 @@ public class Grid extends GridShape
 		coord = "(" + (int)origin.x + "," + (int)origin.y + ")" + coord; //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
 		
 		//add options
-		code+="[gridwidth="+(gridWidth/ppc); //$NON-NLS-1$
-		code+=",subgridwidth="+(subGridWidth/ppc); //$NON-NLS-1$
+		code+="[gridwidth="+LaTeXDrawNumber.getCutNumber(gridWidth/ppc,0.0001); //$NON-NLS-1$
+		code+=",subgridwidth="+LaTeXDrawNumber.getCutNumber(subGridWidth/ppc,0.0001); //$NON-NLS-1$
 		
 		code+=",gridlabels="+(float)(gridLabelsSize*0.6)+"pt"; //$NON-NLS-1$ //$NON-NLS-2$
 		
