@@ -13,6 +13,7 @@ import latexDraw.psTricks.DviPsColors;
 import latexDraw.psTricks.PSTricksConstants;
 import latexDraw.ui.LaTeXDrawFrame;
 import latexDraw.ui.components.Delimitor;
+import latexDraw.util.LaTeXDrawNumber;
 import latexDraw.util.LaTeXDrawPoint2D;
 
 
@@ -302,15 +303,16 @@ public class JoinedLines extends LaTeXDrawPolygon implements Arrowable
 		LaTeXDrawPoint2D d = drawBorders.getOriginPoint(), p;
 		String coord = "", add = "", fillType = "", arrowsCode = ""; //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$//$NON-NLS-4$
 		int i, size = getNbPoints();
-
+		double threshold = 0.001;
+		
 		if(size<2)
 			return null;
 
 		for(i = 0; i<size; i++)
 		{
 			p = pts.elementAt(i);
-			coord += "("+(float)((p.x-d.x)/ppc)+","+ //$NON-NLS-1$ //$NON-NLS-2$
-					(float)((d.y-p.y)/ppc)+")"; //$NON-NLS-1$
+			coord += "("+LaTeXDrawNumber.getCutNumber((float)((p.x-d.x)/ppc),threshold)+","+ //$NON-NLS-1$ //$NON-NLS-2$
+					LaTeXDrawNumber.getCutNumber((float)((d.y-p.y)/ppc),threshold)+")"; //$NON-NLS-1$
 		}
 
 		if(hasShadow)
@@ -320,7 +322,7 @@ public class JoinedLines extends LaTeXDrawPolygon implements Arrowable
 				fillType += ",shadowangle="+(float)Math.toDegrees(shadowAngle);//$NON-NLS-1$
 
 			if(((float)shadowSize)!=((float)DEFAULT_SHADOW_SIZE))
-				fillType += ",shadowsize="+(float)(shadowSize/PPC);//$NON-NLS-1$
+				fillType += ",shadowsize="+LaTeXDrawNumber.getCutNumber((float)(shadowSize/PPC),threshold);//$NON-NLS-1$
 
 			if(!shadowColor.equals(PSTricksConstants.DEFAULT_SHADOW_COLOR))
 			{
@@ -417,7 +419,7 @@ public class JoinedLines extends LaTeXDrawPolygon implements Arrowable
 
 		if(hasDoubleBoundary)
 		{
-			add += ",doubleline=true,doublesep="+(float)(doubleSep/ppc); //$NON-NLS-1$
+			add += ",doubleline=true,doublesep="+LaTeXDrawNumber.getCutNumber((float)(doubleSep/ppc),threshold); //$NON-NLS-1$
 
 			if(doubleColor!=PSTricksConstants.DEFAULT_DOUBLE_COLOR)
 			{
@@ -443,7 +445,7 @@ public class JoinedLines extends LaTeXDrawPolygon implements Arrowable
 			add += ",fillcolor="+name; //$NON-NLS-1$
 		}
 
-		return "\\psline[linewidth="+(thickness/ppc) //$NON-NLS-1$
+		return "\\psline[linewidth="+LaTeXDrawNumber.getCutNumber((thickness/ppc),threshold) //$NON-NLS-1$
 				+add+fillType+"]"+arrowsCode+coord; //$NON-NLS-1$
 	}
 
