@@ -530,7 +530,7 @@ public class LaTeXDrawPolygon extends Figure implements DoubleBoundaryable
 	
 	
 	@Override
-	public synchronized void setLastPoint(LaTeXDrawPoint2D pt)
+	public void setLastPoint(LaTeXDrawPoint2D pt)
 	{
 		// We move the last point of the polygon
 		if(!pts.isEmpty())
@@ -546,7 +546,7 @@ public class LaTeXDrawPolygon extends Figure implements DoubleBoundaryable
 	
 	
 	@Override
-	public synchronized void setFirstPoint(double x, double y)
+	public void setFirstPoint(double x, double y)
 	{
 		// We move the last point of the polygon
 		if(!pts.isEmpty())
@@ -563,7 +563,7 @@ public class LaTeXDrawPolygon extends Figure implements DoubleBoundaryable
 	
 	
 	@Override
-	public synchronized void setLastPoint(double x, double y)
+	public void setLastPoint(double x, double y)
 	{
 		setLastPoint(new LaTeXDrawPoint2D(x,y));
 	}
@@ -575,7 +575,7 @@ public class LaTeXDrawPolygon extends Figure implements DoubleBoundaryable
 	 * @param pt The point which will replace the last point (The last
 	 * point takes the coordinates of this point, the pointer doesn't change).
 	 */
-	public synchronized void setLastPoint(Point pt)
+	public void setLastPoint(Point pt)
 	{
 		setLastPoint(new LaTeXDrawPoint2D(pt.x,pt.y));	
 	}
@@ -672,7 +672,7 @@ public class LaTeXDrawPolygon extends Figure implements DoubleBoundaryable
 	
 	
 	@Override
-	public synchronized String getCodePSTricks(DrawBorders drawBorders, float ppc)
+	public String getCodePSTricks(DrawBorders drawBorders, float ppc)
 	{
 		LaTeXDrawPoint2D d = drawBorders.getOriginPoint(), p;
 		String coord="", add="", fillType=""; //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
@@ -889,7 +889,7 @@ public class LaTeXDrawPolygon extends Figure implements DoubleBoundaryable
 	
 	
 	
-	public synchronized void addRotationAngle(double theta)
+	public void addRotationAngle(double theta)
 	{
 		if(!Double.isInfinite(theta) && !Double.isNaN(theta))
 		{
