@@ -284,7 +284,7 @@ public class LaTeXDrawRectangle extends LaTeXDrawPolygon implements BordersMovab
 
 
 	@Override
-	public LaTeXDrawPoint2D getBordersPoint(int id)
+	public synchronized LaTeXDrawPoint2D getBordersPoint(int id)
 	{
 		if(id == -1)
 			return getPoint(getNbPoints()-1);
