@@ -483,7 +483,7 @@ public class Line extends LaTeXDrawPolygon implements Arrowable
 	
 	
 	@Override
-	public void setIsFilled(boolean filled)
+	public synchronized void setIsFilled(boolean filled)
 	{
 		/* A line cannot be filled. */
 	}
@@ -1039,7 +1039,7 @@ public class Line extends LaTeXDrawPolygon implements Arrowable
 	
 	
 	@Override
-	public void updateGravityCenter() 
+	public synchronized void updateGravityCenter() 
 	{
 		if(pts.size()==LINE_NB_POINTS)
 		{
@@ -1074,7 +1074,7 @@ public class Line extends LaTeXDrawPolygon implements Arrowable
 	
 	
 	@Override
-	public LaTeXDrawRectangle getBorders()
+	public synchronized LaTeXDrawRectangle getBorders()
 	{ 
 		LaTeXDrawPoint2D NW = (LaTeXDrawPoint2D)getTheNWPoint().clone();
 		LaTeXDrawPoint2D SE = (LaTeXDrawPoint2D)getTheSEPoint().clone();
@@ -1159,7 +1159,7 @@ public class Line extends LaTeXDrawPolygon implements Arrowable
 	
 	
 	@Override
-	public LaTeXDrawPoint2D getBordersPoint(int id)
+	public synchronized LaTeXDrawPoint2D getBordersPoint(int id)
 	{
 		LaTeXDrawPoint2D NW = getTheNWPoint();
 		LaTeXDrawPoint2D SE = getTheSEPoint();
