@@ -10,6 +10,7 @@ import java.io.IOException;
 import java.io.ObjectInputStream;
 
 import latexDraw.lang.LaTeXDrawLang;
+import latexDraw.psTricks.PSTricksConstants;
 import latexDraw.ui.LaTeXDrawFrame;
 import latexDraw.ui.components.MagneticGrid;
 import latexDraw.util.LaTeXDrawException;
@@ -70,6 +71,7 @@ public class Picture extends Figure
 		isThicknessable 	= false;
 		canBeFilled 		= false;
 		position 			= new LaTeXDrawPoint2D();
+		borders 			= new LaTeXDrawRectangle(false);
 	}
 
 	
@@ -146,11 +148,19 @@ public class Picture extends Figure
 		if(pathSource==null || picture==null)
 			return ;
 		
-		String name = pathSource.substring(pathSource.lastIndexOf(File.separator)+1, pathSource.lastIndexOf('.'))+LaTeXDrawResources.EPS_EXTENSION;
-		pathTarget = pathSource+File.separator+name;
+		int indexName = pathSource.lastIndexOf(File.separator)+1;
+		String name = pathSource.substring(indexName, pathSource.lastIndexOf('.'))+LaTeXDrawResources.EPS_EXTENSION;
+		String dirPath = pathSource.substring(0, indexName);
+		pathTarget = dirPath+name;
 		File file = new File(pathTarget);
-	
-		if(!file.canWrite())
+		boolean created;
+		
+		try {// We create the output file that will contains the eps picture.
+			created = file.createNewFile();
+		}catch(IOException ex) { created = false; }
+		
+		// If created is false, it may mean that the file already exist.
+		if(!created && !file.canWrite())
 		{
 			pathTarget = LaTeXDrawFrame.getPathExport()+File.separator+name;
 			file = new File(pathTarget);
@@ -158,9 +168,14 @@ public class Picture extends Figure
 		
 		try
 		{
+			// Within jlibeps, graphics are defined using 72 DPI (72/2.54=28,3465 PPC), but latexdraw uses 50 PPC.
+			// That's why, we need the scale the graphics to have a 50 PPC eps picture.
+			double scale = 72. / PSTricksConstants.INCH_VAL_CM / Figure.PPC;// 72 DPI / 2.54 / 50 PPC
 			FileOutputStream finalImage = new FileOutputStream(file);
-			EpsGraphics2D g = new EpsGraphics2D("LaTeXDrawPicture", finalImage, 0, 0, picture.getWidth(null), picture.getHeight(null));//$NON-NLS-1$
+			EpsGraphics2D g = new EpsGraphics2D("LaTeXDrawPicture", finalImage, 0, 0, //$NON-NLS-1$
+									(int)(picture.getWidth(null)*scale), (int)(picture.getHeight(null)*scale));
 			
+			g.scale(scale, scale);
 			g.drawImage(picture, 0, 0, null);
 			g.flush();
 			g.close();
@@ -326,7 +341,7 @@ public class Picture extends Figure
 		LaTeXDrawPoint2D NW = borders.getTheNWPoint();
 		LaTeXDrawPoint2D SE = borders.getTheSEPoint();
 		float x = LaTeXDrawNumber.getCutNumber((float)((position.x+(SE.x-NW.x)/2.-d.x)/ppc),threshold);
-		float y = LaTeXDrawNumber.getCutNumber((float)(((d.y-position.y)/ppc)),threshold);
+		float y = LaTeXDrawNumber.getCutNumber((float)(((d.y-position.y-(SE.y-NW.y)/2.)/ppc)),threshold);
 
 		if(rotationAngle%(Math.PI*2)!=0.)
 		{
