@@ -16,6 +16,7 @@ import latexDraw.psTricks.PSTricksConstants;
 import latexDraw.ui.LaTeXDrawFrame;
 import latexDraw.ui.components.Delimitor;
 import latexDraw.ui.components.MagneticGrid;
+import latexDraw.util.LaTeXDrawNumber;
 import latexDraw.util.LaTeXDrawPoint2D;
 
 
@@ -394,6 +395,7 @@ public class Rhombus extends LaTeXDrawPolygon implements BordersMovable
 		double Xcenter = (pt1.x+pt2.x)/2. - d.x, Ycenter = d.y - (pt1.y+pt3.y)/2.;
 		String add="", fillType=""; //$NON-NLS-1$ //$NON-NLS-2$
 		boolean isFilledWasChanged = false;
+		double threshold = 0.0001;
 		
 		if(hasShadow)
 		{
@@ -402,7 +404,7 @@ public class Rhombus extends LaTeXDrawPolygon implements BordersMovable
 				fillType+=",shadowangle="+(float)(Math.toDegrees(shadowAngle)-Math.toDegrees(rotationAngle));//$NON-NLS-1$
 			
 			if(((float)shadowSize)!=((float)DEFAULT_SHADOW_SIZE))
-				fillType+=",shadowsize="+(float)(shadowSize/PPC);//$NON-NLS-1$
+				fillType+=",shadowsize="+LaTeXDrawNumber.getCutNumber((float)(shadowSize/PPC),threshold);//$NON-NLS-1$
 			
 			if(!shadowColor.equals(PSTricksConstants.DEFAULT_SHADOW_COLOR))
 			{
@@ -431,7 +433,7 @@ public class Rhombus extends LaTeXDrawPolygon implements BordersMovable
 		
 		if(hasDoubleBoundary)
 		{
-			add+=",doubleline=true,doublesep="+(float)(doubleSep/ppc); //$NON-NLS-1$
+			add+=",doubleline=true,doublesep="+LaTeXDrawNumber.getCutNumber((float)(doubleSep/ppc),threshold); //$NON-NLS-1$
 			
 			if(doubleColor!=PSTricksConstants.DEFAULT_DOUBLE_COLOR)
 			{
@@ -448,14 +450,12 @@ public class Rhombus extends LaTeXDrawPolygon implements BordersMovable
 		if(rotationAngle%(Math.PI*2)!=0)
 			add+=",gangle="+(float)Math.toDegrees(-rotationAngle);//$NON-NLS-1$
 		
-		if(Math.abs(Xcenter) < 0.001) Xcenter = 0;
-		if(Math.abs(Ycenter) < 0.001) Ycenter = 0;
 		if(isFilledWasChanged) isFilled = false;
 		
-		return "\\psdiamond[linewidth=" + (thickness/ppc) +  //$NON-NLS-1$
-		add + fillType + "](" + (float)(Xcenter/ppc) + ',' +  //$NON-NLS-1$
-		(float)(Ycenter/ppc) + ")("  //$NON-NLS-1$
-			+ (float)((Math.abs(pt1.x-pt2.x)/2.)/ppc) + ',' + (float)((Math.abs(pt1.y-pt3.y)/2.)/ppc) + ')';
+		return "\\psdiamond[linewidth=" + LaTeXDrawNumber.getCutNumber((thickness/ppc),threshold) +  //$NON-NLS-1$
+		add + fillType + "](" + LaTeXDrawNumber.getCutNumber((float)(Xcenter/ppc),threshold) + ',' +  //$NON-NLS-1$
+		LaTeXDrawNumber.getCutNumber((float)(Ycenter/ppc),threshold) + ")("  //$NON-NLS-1$
+			+ LaTeXDrawNumber.getCutNumber((float)((Math.abs(pt1.x-pt2.x)/2.)/ppc),threshold) + ',' + LaTeXDrawNumber.getCutNumber((float)((Math.abs(pt1.y-pt3.y)/2.)/ppc),threshold) + ')';
 	}
 	
 	
@@ -703,13 +703,15 @@ public class Rhombus extends LaTeXDrawPolygon implements BordersMovable
 		LaTeXDrawPoint2D pt1 = getPoint(0), pt2 = getPoint(-1);
 		GeneralPath gp = new GeneralPath();
 		
-		if(pt1.x<pt2.x+thickness && pt1.x>pt2.x-thickness)
-		{
+		if(pt1.x<pt2.x+thickness && pt1.x>pt2.x-thickness) {
 			gp.moveTo((float)(pt1.x+pt2.x)/2f, (float)pt1.y);
 			gp.lineTo((float)(pt1.x+pt2.x)/2f, (float)pt2.y);
 		}
-		else
-		{
+		else if(pt1.y<pt2.y+thickness && pt1.y>pt2.y-thickness) {
+			gp.moveTo((float)pt1.x, (float)(pt1.y+pt2.y)/2f);
+			gp.lineTo((float)pt2.x, (float)(pt1.y+pt2.y)/2f);
+		}
+		else {
 			if(!into) 
 				gap*=-1;
 			
@@ -965,7 +967,8 @@ public class Rhombus extends LaTeXDrawPolygon implements BordersMovable
 	public String getPSTricksCodeFilling(float ppc)
 	{
 		String str="fillstyle=";//$NON-NLS-1$
-
+		double threshold = 0.001;
+		
 		if(hatchingStyle.equals(PSTricksConstants.TOKEN_FILL_NONE))
 		{
 			if(isFilled)
@@ -1018,7 +1021,7 @@ public class Rhombus extends LaTeXDrawPolygon implements BordersMovable
 				if(isFilled)
 					str += "*"; //$NON-NLS-1$
 	
-				str += ",hatchwidth=" + (hatchingWidth / PPC) + ",hatchangle=" + //$NON-NLS-1$ //$NON-NLS-2$
+				str += ",hatchwidth=" + LaTeXDrawNumber.getCutNumber(hatchingWidth/PPC,threshold) + ",hatchangle=" + //$NON-NLS-1$ //$NON-NLS-2$
 						(float)((-Math.toDegrees(rotationAngle))%360.);
 				//TODO hatching angle
 				if(!hatchingColor.equals(PSTricksConstants.DEFAULT_HATCHING_COLOR))
