@@ -860,7 +860,7 @@ public class Square extends LaTeXDrawRectangle
 	
 	
 	@Override
-	public void onClick(Point p)
+	public synchronized void onClick(Point p)
 	{
 		updateNSEWDelimitors();
 		
