@@ -18,6 +18,7 @@ import latexDraw.psTricks.PSTricksConstants;
 import latexDraw.ui.DrawContainer;
 import latexDraw.ui.LaTeXDrawFrame;
 import latexDraw.ui.components.MagneticGrid;
+import latexDraw.util.LaTeXDrawNumber;
 import latexDraw.util.LaTeXDrawPoint2D;
 
 
@@ -360,6 +361,10 @@ public class Text extends Figure
 	
 	/** The palatino font */
 	public static final TextFont TEXTFONT_PALATINO = new TextFont("Palatino Linotype", "ppl", "T1"); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
+
+	public static final TextFont TEXTFONT_DIALOG = new TextFont("Dialog", "Dialog.plain", "T1"); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
+	
+	public static final TextFont TEXTFONT_DIALOG2 = new TextFont("Dialog", "Dialog", "T1"); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
 	
 	/** The font used by default */
 	public static final TextFont DEFAULT_TEXTFONT = TEXTFONT_TIMES;
@@ -1027,7 +1032,7 @@ public class Text extends Figure
 		if(name.equals(TEXTFONT_COURIER.getName()))
 			currentTextFont = TEXTFONT_COURIER;
 		else
-		if(name.equals(TEXTFONT_PALATINO.getName()))
+		if(name.equals(TEXTFONT_PALATINO.getName()) || name.equals(TEXTFONT_DIALOG.getName()))
 			currentTextFont = TEXTFONT_PALATINO;
 		
 		updateFont();
@@ -1046,13 +1051,17 @@ public class Text extends Figure
 		if(fam==null)
 			return ;
 		
-		if(fam.equals(TEXTFONT_TIMES.getFamily()))
+		String fam2 = fam.toLowerCase().replaceAll("'", "").replaceAll("\"", "");
+		
+		if(fam2.equals(TEXTFONT_TIMES.getFamily().toLowerCase()))
 			currentTextFont = TEXTFONT_TIMES;
 		else
-		if(fam.equals(TEXTFONT_COURIER.getFamily()))
+		if(fam2.equals(TEXTFONT_COURIER.getFamily().toLowerCase()))
 			currentTextFont = TEXTFONT_COURIER;
 		else
-		if(fam.equals(TEXTFONT_PALATINO.getFamily()))
+		if(fam2.equals(TEXTFONT_PALATINO.getFamily().toLowerCase()) || 
+				fam2.equals(TEXTFONT_DIALOG.getFamily().toLowerCase()) ||
+				fam2.equals(TEXTFONT_DIALOG2.getFamily().toLowerCase()))
 			currentTextFont = TEXTFONT_PALATINO;
 		
 		updateFont();
@@ -1117,42 +1126,8 @@ public class Text extends Figure
 	 * @param size The new size (must corresponds to the size of one of the SIZE_XXX constants.
 	 * @since 2.0.0
 	 */
-	public synchronized void setSize(int size)
-	{
-		TextSize ts = null;
-		
-		if(size==SIZE_FOOTNOTE.getSize())
-			ts = SIZE_FOOTNOTE;
-		else
-		if(size==SIZE_HUGE1.getSize())
-			ts = SIZE_HUGE1;
-		else
-		if(size==SIZE_HUGE2.getSize())
-			ts = SIZE_HUGE2;
-		else
-		if(size==SIZE_LARGE1.getSize())
-			ts = SIZE_LARGE1;
-		else
-		if(size==SIZE_LARGE2.getSize())
-			ts = SIZE_LARGE2;
-		else
-		if(size==SIZE_LARGE3.getSize())
-			ts = SIZE_LARGE3;
-		else
-		if(size==SIZE_NORMAL.getSize())
-			ts = SIZE_NORMAL;
-		else
-		if(size==SIZE_SCRIPT.getSize())
-			ts = SIZE_SCRIPT;
-		else
-		if(size==SIZE_SMALL.getSize())
-			ts = SIZE_SMALL;
-		else
-		if(size==SIZE_TINY.getSize())
-			ts = SIZE_TINY;
-		
-		if(ts!=null)
-			setSize(ts.getLabel());
+	public synchronized void setSize(float size) {
+		setSize(getClosestTextSize(size).getLabel());
 	}
 	
 	
@@ -1258,6 +1233,7 @@ public class Text extends Figure
 	{
 		if(text==null || text.length()==0) return null;
 		
+		double threshold = 0.001;
 		String addBegin="", addEnd="", size="", font=""; //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$ //$NON-NLS-4$
 		LaTeXDrawPoint2D d = drawBorders.getOriginPoint();
 		double yGap = 0;
@@ -1274,14 +1250,15 @@ public class Text extends Figure
 		
 		if(rotationAngle%(Math.PI*2)!=0.)
 		{
-			double angle = -Math.toDegrees(rotationAngle);
-			double cx = (gravityCenter.x-d.x)/ppc;
-			double cy = (d.y-gravityCenter.y)/ppc;
-			double x2 = -Math.cos(-rotationAngle)*cx+
-						Math.sin(-rotationAngle)*cy+cx;
-			double y2 =  -Math.sin(-rotationAngle)*cx-
-						Math.cos(-rotationAngle)*cy+cy;
-			addBegin +="\\rput{"+(float)angle+ "}("+(float)x2+','+(float)y2+"){"; //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
+			float angle = LaTeXDrawNumber.getCutNumber((float)-Math.toDegrees(rotationAngle), threshold);
+			float cx = LaTeXDrawNumber.getCutNumber((float)((gravityCenter.x-d.x)/ppc), threshold);
+			float cy = LaTeXDrawNumber.getCutNumber((float)((d.y-gravityCenter.y)/ppc), threshold);
+			float x2 = LaTeXDrawNumber.getCutNumber((float)(-Math.cos(-rotationAngle)*cx+
+						Math.sin(-rotationAngle)*cy+cx), threshold);
+			float y2 =  LaTeXDrawNumber.getCutNumber((float)(-Math.sin(-rotationAngle)*cx-
+						Math.cos(-rotationAngle)*cy+cy), threshold);
+			
+			addBegin +="\\rput{"+angle+ "}("+x2+','+y2+"){"; //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
 			addEnd = "}"; //$NON-NLS-1$
 		}
 		
@@ -2160,4 +2137,33 @@ public class Text extends Figure
 	{
 		return multipleBoxDisplay;
 	}
+	
+	
+	/**
+	 * @param size The size to test.
+	 * @return The text size constant that has the closest size than the given size.
+	 */
+	public static TextSize getClosestTextSize(float size) {
+		if(size<=SIZE_TINY.getSize())
+			return SIZE_TINY;
+		if(size<=SIZE_SCRIPT.getSize())
+			return (SIZE_SCRIPT.getSize()-size)<Math.abs(SIZE_TINY.getSize()-size) ? SIZE_SCRIPT : SIZE_TINY;
+		if(size<=SIZE_FOOTNOTE.getSize())
+			return (SIZE_FOOTNOTE.getSize()-size)<Math.abs(SIZE_SCRIPT.getSize()-size) ? SIZE_FOOTNOTE : SIZE_SCRIPT;
+		if(size<=SIZE_SMALL.getSize())
+			return (SIZE_SMALL.getSize()-size)<Math.abs(SIZE_FOOTNOTE.getSize()-size) ? SIZE_SMALL : SIZE_FOOTNOTE;
+		if(size<=SIZE_NORMAL.getSize())
+			return (SIZE_NORMAL.getSize()-size)<Math.abs(SIZE_SMALL.getSize()-size) ? SIZE_NORMAL : SIZE_SMALL;
+		if(size<=SIZE_LARGE1.getSize())
+			return (SIZE_LARGE1.getSize()-size)<Math.abs(SIZE_NORMAL.getSize()-size) ? SIZE_LARGE1 : SIZE_NORMAL;
+		if(size<=SIZE_LARGE2.getSize())
+			return (SIZE_LARGE2.getSize()-size)<Math.abs(SIZE_LARGE1.getSize()-size) ? SIZE_LARGE2 : SIZE_LARGE1;
+		if(size<=SIZE_LARGE3.getSize())
+			return (SIZE_LARGE3.getSize()-size)<Math.abs(SIZE_LARGE2.getSize()-size) ? SIZE_LARGE3 : SIZE_LARGE2;
+		if(size<=SIZE_HUGE1.getSize())
+			return (SIZE_HUGE1.getSize()-size)<Math.abs(SIZE_LARGE3.getSize()-size) ? SIZE_HUGE1 : SIZE_LARGE3;
+		if(size<=SIZE_HUGE2.getSize())
+			return (SIZE_HUGE2.getSize()-size)<Math.abs(SIZE_HUGE1.getSize()-size) ? SIZE_HUGE2 : SIZE_HUGE1;
+		return SIZE_HUGE2;
+	}
 }
