@@ -14,6 +14,7 @@ import latexDraw.psTricks.PSTricksConstants;
 import latexDraw.ui.LaTeXDrawFrame;
 import latexDraw.ui.components.Delimitor;
 import latexDraw.ui.components.MagneticGrid;
+import latexDraw.util.LaTeXDrawNumber;
 import latexDraw.util.LaTeXDrawPoint2D;
 
 
@@ -212,7 +213,7 @@ public class Triangle extends LaTeXDrawPolygon implements BordersMovable
 		}
 		
 		Color formerCol = g.getColor();
-
+		
 		if(hasDoubleBoundary)
 		{
 			Shape s0 = shape;
@@ -442,6 +443,7 @@ public class Triangle extends LaTeXDrawPolygon implements BordersMovable
 		String addEnd = "";//$NON-NLS-1$
 		LaTeXDrawPoint2D pt1 = borders.getPoint(0), pt2 = borders.getPoint(2);
 		boolean isFilledWasChanged = false;
+		double threshold = 0.001;
 		
 		if(pt1.y>pt2.y || rotationAngle%(Math.PI*2)!=0.)
 		{
@@ -464,10 +466,10 @@ public class Triangle extends LaTeXDrawPolygon implements BordersMovable
 		if(hasShadow)
 		{
 			fillType+=",shadow=true";//$NON-NLS-1$
-			fillType+=",shadowangle="+(float)(Math.toDegrees(shadowAngle)-(pt1.y>pt2.y?180:0));//$NON-NLS-1$
+			fillType+=",shadowangle="+LaTeXDrawNumber.getCutNumber((float)(Math.toDegrees(shadowAngle)-(pt1.y>pt2.y?180:0)),threshold);//$NON-NLS-1$
 			
 			if(((float)shadowSize)!=((float)DEFAULT_SHADOW_SIZE))
-				fillType+=",shadowsize="+(float)(shadowSize/PPC);//$NON-NLS-1$
+				fillType+=",shadowsize="+LaTeXDrawNumber.getCutNumber((float)(shadowSize/PPC),threshold);//$NON-NLS-1$
 			
 			if(!shadowColor.equals(PSTricksConstants.DEFAULT_SHADOW_COLOR))
 			{
@@ -496,7 +498,7 @@ public class Triangle extends LaTeXDrawPolygon implements BordersMovable
 
 		if(hasDoubleBoundary)
 		{
-			add+=",doubleline=true,doublesep="+(float)(doubleSep/ppc); //$NON-NLS-1$
+			add+=",doubleline=true,doublesep="+LaTeXDrawNumber.getCutNumber((float)(doubleSep/ppc),threshold); //$NON-NLS-1$
 			
 			if(doubleColor!=PSTricksConstants.DEFAULT_DOUBLE_COLOR)
 			{
@@ -510,15 +512,13 @@ public class Triangle extends LaTeXDrawPolygon implements BordersMovable
 			}
 		}
 		
-		if(Math.abs(baseX) < 0.001) baseX = 0;
-		if(Math.abs(baseY) < 0.001) baseY = 0;
 		if(isFilledWasChanged) isFilled = false;
 		
 		return addBegin+"\\pstriangle[linewidth=" +  //$NON-NLS-1$
-				  (thickness/ppc ) + add + fillType + "]("  //$NON-NLS-1$
-				+ (baseX/ppc) + ',' + (baseY/ppc) + ")("  //$NON-NLS-1$
-				+ (float)(Math.abs(NW.x-SE.x)/ppc) + ',' 
-				+ (float)(Math.abs(NW.y-SE.y)/ppc) + ')'+addEnd;
+				LaTeXDrawNumber.getCutNumber(thickness/ppc,threshold) + add + fillType + "]("  //$NON-NLS-1$
+				+ LaTeXDrawNumber.getCutNumber(baseX/ppc, threshold) + ',' + LaTeXDrawNumber.getCutNumber(baseY/ppc, threshold) + ")("  //$NON-NLS-1$
+				+ LaTeXDrawNumber.getCutNumber((float)(Math.abs(NW.x-SE.x)/ppc),threshold) + ',' 
+				+ LaTeXDrawNumber.getCutNumber((float)(Math.abs(NW.y-SE.y)/ppc),threshold) + ')'+addEnd;
 	}
 
 
@@ -734,13 +734,15 @@ public class Triangle extends LaTeXDrawPolygon implements BordersMovable
 		GeneralPath gp = new GeneralPath();
 		LaTeXDrawPoint2D pt1 = getPoint(0), pt2 = getPoint(-1);
 		
-		if(pt1.x<pt2.x+thickness && pt1.x>pt2.x-thickness)
-		{
+		if(pt1.x<pt2.x+thickness && pt1.x>pt2.x-thickness) {
 			gp.moveTo((float)(pt1.x+pt2.x)/2f, (float)pt1.y);
 			gp.lineTo((float)(pt1.x+pt2.x)/2f, (float)pt2.y);
 		}
-		else
-		{
+		else if(pt1.y<pt2.y+thickness && pt1.y>pt2.y-thickness) {
+			gp.moveTo((float)pt1.x, (float)(pt1.y+pt2.y)/2f);
+			gp.lineTo((float)pt2.x, (float)(pt1.y+pt2.y)/2f);
+		}
+		else {
 			if(!into) 
 				gap*=-1;
 			
