@@ -3,16 +3,15 @@ package latexDraw.generators.svg;
 import java.awt.Font;
 import java.awt.FontMetrics;
 import java.awt.geom.Point2D;
-import java.text.ParseException;
 import java.util.Vector;
 
 import latexDraw.figures.*;
-import latexDraw.parsers.latexdraw.PointsParser;
 import latexDraw.parsers.svg.*;
 import latexDraw.parsers.svg.elements.SVGElement;
 import latexDraw.parsers.svg.elements.SVGGElement;
 import latexDraw.parsers.svg.elements.SVGLineElement;
 import latexDraw.parsers.svg.elements.SVGTextElement;
+import latexDraw.parsers.svg.parsers.SVGPointsParser;
 import latexDraw.psTricks.PSTricksConstants;
 import latexDraw.util.LaTeXDrawNamespace;
 import latexDraw.util.LaTeXDrawPoint2D;
@@ -86,70 +85,40 @@ public class LAxeSVGGenerator extends LShapeSVGGenerator
 			try{ axe.setTicksSize(Double.valueOf(str)); }
 			catch(NumberFormatException e) { /* */ }
 			
-		try
-		{
-			values = PointsParser.getPoints(elt.getAttribute(pref+LaTeXDrawNamespace.XML_GRID_END));
+		values = SVGPointsParser.getPoints(elt.getAttribute(pref+LaTeXDrawNamespace.XML_GRID_END));
+		
+		if(values!=null && values.size()>0) { 
+			axe.setGridEndX((int)values.elementAt(0).getX());  
+			axe.setGridEndY((int)values.elementAt(0).getY());  
+		}
+	
+		values = SVGPointsParser.getPoints(elt.getAttribute(pref+LaTeXDrawNamespace.XML_GRID_START));
+		
+		if(values!=null && values.size()>0) { 
+			axe.setGridStartX((int)values.elementAt(0).getX());  
+			axe.setGridStartY((int)values.elementAt(0).getY());  
+		}
+		
+		values = SVGPointsParser.getPoints(elt.getAttribute(pref+LaTeXDrawNamespace.XML_GRID_ORIGIN));
+	
+		if(values!=null && values.size()>0) { 
+			axe.setOriginX((int)values.elementAt(0).getX());  
+			axe.setOriginY((int)values.elementAt(0).getY());  
+		}
+		
+		values = SVGPointsParser.getPoints(elt.getAttribute(pref+LaTeXDrawNamespace.XML_AXE_INCREMENT));
 			
-			if(values!=null && values.size()>0)
-			{ 
-				axe.setGridEndX((int)values.elementAt(0).getX());  
-				axe.setGridEndY((int)values.elementAt(0).getY());  
-			}
+		if(values!=null && values.size()>0) { 
+			axe.setIncrementX(values.elementAt(0).getX());  
+			axe.setIncrementY(values.elementAt(0).getY());  
 		}
-		catch(ParseException e) { e.printStackTrace(); }
-		catch(NumberFormatException e) { e.printStackTrace(); }
 		
-		try
-		{
-			values = PointsParser.getPoints(elt.getAttribute(pref+LaTeXDrawNamespace.XML_GRID_START));
+		values = SVGPointsParser.getPoints(elt.getAttribute(pref+LaTeXDrawNamespace.XML_AXE_DIST_LABELS));
 			
-			if(values!=null && values.size()>0)
-			{ 
-				axe.setGridStartX((int)values.elementAt(0).getX());  
-				axe.setGridStartY((int)values.elementAt(0).getY());  
-			}
+		if(values!=null && values.size()>0) { 
+			axe.setDistLabelsX(values.elementAt(0).getX());  
+			axe.setDistLabelsY(values.elementAt(0).getY());  
 		}
-		catch(ParseException e) { e.printStackTrace(); }
-		catch(NumberFormatException e) { e.printStackTrace(); }
-		
-		try
-		{
-			values = PointsParser.getPoints(elt.getAttribute(pref+LaTeXDrawNamespace.XML_GRID_ORIGIN));
-		
-			if(values!=null && values.size()>0)
-			{ 
-				axe.setOriginX((int)values.elementAt(0).getX());  
-				axe.setOriginY((int)values.elementAt(0).getY());  
-			}
-		}
-		catch(ParseException e) { e.printStackTrace(); }
-		catch(NumberFormatException e) { e.printStackTrace(); }
-		
-		try
-		{
-			values = PointsParser.getPoints(elt.getAttribute(pref+LaTeXDrawNamespace.XML_AXE_INCREMENT));
-				
-			if(values!=null && values.size()>0)
-			{ 
-				axe.setIncrementX(values.elementAt(0).getX());  
-				axe.setIncrementY(values.elementAt(0).getY());  
-			}
-		}
-		catch(ParseException e) { e.printStackTrace(); }
-		catch(NumberFormatException e) { e.printStackTrace(); }
-			
-		try
-		{
-			values = PointsParser.getPoints(elt.getAttribute(pref+LaTeXDrawNamespace.XML_AXE_DIST_LABELS));
-				
-			if(values!=null && values.size()>0)
-			{ 
-				axe.setDistLabelsX(values.elementAt(0).getX());  
-				axe.setDistLabelsY(values.elementAt(0).getY());  
-			}
-		}
-		catch(ParseException e) { e.printStackTrace(); }
-		catch(NumberFormatException e) { e.printStackTrace(); }
 		
 		/* Looking for the two axe in order to get the position of the axes. */
 		SVGNodeList nl = elt.getChildren(SVGElements.SVG_G);
