@@ -3,15 +3,17 @@ package latexDraw.generators.svg;
 import java.awt.Color;
 import java.awt.FontMetrics;
 import java.awt.geom.Point2D;
-import java.text.ParseException;
 import java.util.Vector;
 
 import latexDraw.figures.Figure;
 import latexDraw.figures.Grid;
 import latexDraw.figures.LaTeXDrawRectangle;
-import latexDraw.parsers.latexdraw.PointsParser;
-import latexDraw.parsers.svg.*;
+import latexDraw.parsers.svg.CSSColors;
+import latexDraw.parsers.svg.SVGAttributes;
+import latexDraw.parsers.svg.SVGDocument;
+import latexDraw.parsers.svg.SVGTransform;
 import latexDraw.parsers.svg.elements.*;
+import latexDraw.parsers.svg.parsers.SVGPointsParser;
 import latexDraw.util.LaTeXDrawNamespace;
 import latexDraw.util.LaTeXDrawPoint2D;
 
@@ -69,44 +71,26 @@ public class LGridSVGGenerator extends LShapeSVGGenerator
 		
 		g.setLinesColor(elt.getStroke());
 		
-		try
-		{
-			values = PointsParser.getPoints(elt.getAttribute(pref+LaTeXDrawNamespace.XML_GRID_END));
-				
-			if(values!=null && values.size()>0)
-			{ 
-				g.setGridEndX((int)values.elementAt(0).getX());  
-				g.setGridEndY((int)values.elementAt(0).getY());  
-			}
-		}
-		catch(ParseException e) { e.printStackTrace(); }
-		catch(NumberFormatException e) { e.printStackTrace(); }
-		
-		try
-		{
-			values = PointsParser.getPoints(elt.getAttribute(pref+LaTeXDrawNamespace.XML_GRID_START));
+		values = SVGPointsParser.getPoints(elt.getAttribute(pref+LaTeXDrawNamespace.XML_GRID_END));
 			
-			if(values!=null && values.size()>0)
-			{ 
-				g.setGridStartX((int)values.elementAt(0).getX());  
-				g.setGridStartY((int)values.elementAt(0).getY());  
-			}
+		if(values!=null && values.size()>0) { 
+			g.setGridEndX((int)values.elementAt(0).getX());  
+			g.setGridEndY((int)values.elementAt(0).getY());  
 		}
-		catch(ParseException e) { e.printStackTrace(); }
-		catch(NumberFormatException e) { e.printStackTrace(); }
-		
-		try
-		{
-			values = PointsParser.getPoints(elt.getAttribute(pref+LaTeXDrawNamespace.XML_GRID_ORIGIN));
 	
-			if(values!=null && values.size()>0)
-			{ 
-				g.setOriginX((int)values.elementAt(0).getX());  
-				g.setOriginY((int)values.elementAt(0).getY());  
-			}
+		values = SVGPointsParser.getPoints(elt.getAttribute(pref+LaTeXDrawNamespace.XML_GRID_START));
+		
+		if(values!=null && values.size()>0) { 
+			g.setGridStartX((int)values.elementAt(0).getX());  
+			g.setGridStartY((int)values.elementAt(0).getY());  
+		}
+	
+		values = SVGPointsParser.getPoints(elt.getAttribute(pref+LaTeXDrawNamespace.XML_GRID_ORIGIN));
+
+		if(values!=null && values.size()>0) { 
+			g.setOriginX((int)values.elementAt(0).getX());  
+			g.setOriginY((int)values.elementAt(0).getY());  
 		}
-		catch(ParseException e) { e.printStackTrace(); }
-		catch(NumberFormatException e) { e.printStackTrace(); }
 		
 		v = elt.getAttribute(pref+LaTeXDrawNamespace.XML_GRID_X_SOUTH);
 		
