@@ -1034,9 +1034,9 @@ public abstract class LShapeSVGGenerator
         	gap = 0;
         else 
         	if(shape.getBordersPosition().equals(PSTricksConstants.BORDERS_INSIDE))
-        		gap = -shape.getThickness() - (shape.hasDoubleBoundary() ? (float)shape.getDoubleSep()/2f + shape.getThickness() : 0) ;
+        		gap = -shape.getThickness() - (shape.hasDoubleBoundary() ? (float)shape.getDoubleSep() + shape.getThickness() : 0) ;
         	else
-        		gap = shape.getThickness() + (shape.hasDoubleBoundary() ? (float)shape.getDoubleSep()/2f + shape.getThickness() : 0);
+        		gap = shape.getThickness() + (shape.hasDoubleBoundary() ? (float)shape.getDoubleSep() + shape.getThickness() : 0);
         
         return gap;
 	}
