@@ -2,6 +2,7 @@ package latexDraw.installer;
 
 import java.awt.BorderLayout;
 import java.awt.Color;
+import java.awt.Component;
 import java.awt.Dimension;
 import java.awt.Toolkit;
 import java.io.*;
@@ -39,6 +40,9 @@ public final class InstallerUI extends JFrame implements Runnable
 
 	/** The name of the os. */
 	protected String os;
+	
+	/** The java jre */
+	protected String javaVersion;
 
 	/** The listener of the installer. */
 	protected transient InstallerListener listener;
@@ -128,6 +132,7 @@ public final class InstallerUI extends JFrame implements Runnable
 		
 		pathJar = LaTeXDrawPath.getPathJar();
 		os = System.getProperty("os.name");//$NON-NLS-1$
+		javaVersion = System.getProperty("java.version");//$NON-NLS-1$
 		listener = new InstallerListener(this);
 		slidePosition = 1;
 		
@@ -143,12 +148,14 @@ public final class InstallerUI extends JFrame implements Runnable
 			
 		setIconImage(Toolkit.getDefaultToolkit().getImage(getClass().getClassLoader().getResource("res/LaTeXDrawIcon.png")));//$NON-NLS-1$
 		setDefaultCloseOperation(WindowConstants.EXIT_ON_CLOSE);
+		
+		JPanel ctrlPanel = createControlButtonsPanel();
 		createStartPanel();
 		
 		getContentPane().setLayout(new BorderLayout());
 		getContentPane().add(createHeaderPanel(), BorderLayout.NORTH);
 		getContentPane().add(panel1, BorderLayout.CENTER);
-		getContentPane().add(createControlButtonsPanel(), BorderLayout.SOUTH);
+		getContentPane().add(ctrlPanel, BorderLayout.SOUTH);
 		
 		previousB.setEnabled(false);
 		Dimension dim = Toolkit.getDefaultToolkit().getScreenSize();
@@ -165,17 +172,47 @@ public final class InstallerUI extends JFrame implements Runnable
 	protected final void createStartPanel()
 	{
 		panel1 = new JPanel();
+		setPanelDimension(panel1);
+		
 		String plus;
 		
-		if(os.toLowerCase().contains("vista"))//$NON-NLS-1$
-			plus = "</li><br><li>Be careful with Vista! Files\".<br>You must have launched this installer via the script install_vista.vbs.";
-		else
-			plus = "";//$NON-NLS-1$
+		panel1.setLayout(new BoxLayout(panel1, BoxLayout.Y_AXIS));
 		
-		panel1.add(new JLabel("<html><br><br><br><ul><li>"+"This installer will, create the necessary directories, place the templates in your profile<br>and place the latexdraw files in the chosen directory."+//$NON-NLS-1$
-				"</li><br><li>"+"You may need to be administrator/root to install LaTeXDraw."+ plus+"</li></ul></html>"), BorderLayout.CENTER);//$NON-NLS-1$//$NON-NLS-3$
-		
-		setPanelDimension(panel1);
+		if(javaVersion.startsWith("1.5")) {
+			JTextArea textArea 	= new JTextArea();
+			JLabel label 		= new JLabel();
+			JLabel label2 		= new JLabel();
+			JLabel label3 		= new JLabel();
+			
+			textArea.setEditable(false);
+			
+			label.setText("You must have Java 6 installed.");
+			label2.setText("Your current version of Java is " + javaVersion + ".");
+			label3.setText("You can download the last version of java here:");
+			
+			textArea.setText("http://www.java.com/fr/download/index.jsp");
+			textArea.setMaximumSize(new Dimension(300,20));
+			label.setAlignmentX(Component.CENTER_ALIGNMENT);
+			label2.setAlignmentX(Component.CENTER_ALIGNMENT);
+			label3.setAlignmentX(Component.CENTER_ALIGNMENT);
+			textArea.setAlignmentX(Component.CENTER_ALIGNMENT);
+			
+			panel1.add(Box.createVerticalStrut(60));
+			panel1.add(label);
+			panel1.add(label2);
+			panel1.add(label3);
+			panel1.add(Box.createVerticalStrut(10));
+			panel1.add(textArea);
+			nextB.setEnabled(false);
+		} else {
+			if(os.toLowerCase().contains("vista"))//$NON-NLS-1$
+				plus = "</li><br><li>Be careful with Vista! Files\".<br>You must have launched this installer via the script install_vista.vbs.";
+			else
+				plus = "";//$NON-NLS-1$
+			
+			panel1.add(new JLabel("<html><br><br><br><ul><li>"+"This installer will, create the necessary directories, place the templates in your profile<br>and place the latexdraw files in the chosen directory."+//$NON-NLS-1$
+					"</li><br><li>"+"You may need to be administrator/root to install LaTeXDraw."+ plus+"</li></ul></html>"));//$NON-NLS-1$//$NON-NLS-3$
+		}
 	}
 	
 	
