@@ -57,6 +57,8 @@ public abstract class LaTeXDrawLang
 	public static final String LANG_IT = "Italiano";//$NON-NLS-1$
 	
 	public static final String LANG_PL = "Język polski";//$NON-NLS-1$
+
+	public static final String LANG_TR = "Türkçe";//$NON-NLS-1$
 	
 	public static final String MISSING_KEY = "missingKey";//$NON-NLS-1$
 	
@@ -76,6 +78,8 @@ public abstract class LaTeXDrawLang
 	
 	public static final String TOKEN_LANG_PL = "lang.pl";//$NON-NLS-1$
 	
+	public static final String TOKEN_LANG_TR = "lang.tr";//$NON-NLS-1$
+	
 	public static final String LANG_DEFAULT = LANG_EN;
 	
 	private static ResourceBundle resourceBundleLaTeXDrawFrame = ResourceBundle.getBundle(
@@ -284,6 +288,9 @@ public abstract class LaTeXDrawLang
 			if(userLang.equals("pl")) //$NON-NLS-1$
 				return LaTeXDrawLang.LANG_PL;
 			
+			if(userLang.equals("tr")) //$NON-NLS-1$
+				return LaTeXDrawLang.LANG_TR;
+			
 			return LaTeXDrawLang.LANG_DEFAULT; 
 		}
 		
@@ -318,6 +325,9 @@ public abstract class LaTeXDrawLang
 			if(userLang.equals("pl"))//$NON-NLS-1$
 				return TOKEN_LANG_PL;
 			
+			if(userLang.equals("tr"))//$NON-NLS-1$
+				return TOKEN_LANG_TR;
+			
 			return TOKEN_LANG_EN;
 		}
 		
@@ -338,6 +348,9 @@ public abstract class LaTeXDrawLang
 		
 		if(langCurrent.equals(LANG_PL))
 			return TOKEN_LANG_PL;
+		
+		if(langCurrent.equals(LANG_TR))
+			return TOKEN_LANG_TR;
 		 
 		return TOKEN_LANG_EN;
 	}
@@ -362,7 +375,7 @@ public abstract class LaTeXDrawLang
 		if(lang!=null && (lang.equals(LANG_DE) || 
 			lang.equals(LANG_EN) || lang.equals(LANG_EN_US) ||
 			lang.equals(LANG_ES) || lang.equals(LANG_FR) || 
-			lang.equals(LANG_IT) || lang.equals(LANG_PL)))
+			lang.equals(LANG_IT) || lang.equals(LANG_PL) || lang.equals(LANG_TR)))
 			langCurrent = lang;
 	}
 }
