@@ -233,6 +233,12 @@ public class LPSTParser extends PSTParser
 								else ok = false;
 								break;
 								
+							case '{' : // \{
+							case '}' : // \}
+							case '$' : // \$
+							case '&' : // \&
+							case '#' : // \#
+							case '%' : // \%
 							case '\\': // \\
 								setPosition(getPosition()-1);
 								addParsedText();
