@@ -1446,13 +1446,20 @@ public class PSTParametersParser extends CodeParser
 	}
 
 	
+	
+	@Override
+	public boolean isComment()
+	{
+		return getChar()=='%';
+	}
+	
 
 	@Override
 	public String skipComment()
 	{
 		String comment;
 		
-		if(getChar()=='%')
+		if(isComment())
 		{
 			comment = "";
 			char c;
