@@ -93,8 +93,11 @@ public abstract class SVGAttributes
 	public static final String SVG_TRANSFORM_SKEW_X			= "skewX";							//$NON-NLS-1$
 	public static final String SVG_TRANSFORM_SKEW_Y			= "skewY";							//$NON-NLS-1$
 
+	public static final String SVG_FONT_STYLE_NORMAL		= "normal";							//$NON-NLS-1$
+	public static final String SVG_FONT_STYLE_OBLIQUE		= "oblique";						//$NON-NLS-1$
 	public static final String SVG_FONT_STYLE_ITALIC		= "italic";							//$NON-NLS-1$
 	public static final String SVG_FONT_WEIGHT_BOLD			= "bold";							//$NON-NLS-1$
+	public static final String SVG_FONT_WEIGHT_NORMAL		= "normal";							//$NON-NLS-1$
 	
 //	public static final String SVG_TEXT_ANCHOR				= "text-anchor";					//$NON-NLS-1$
 //	public static final String SVG_TEXT_ANCHOR_VALUE_END	= "end";							//$NON-NLS-1$
