@@ -103,6 +103,8 @@ public class SVGElementsFactory
 					return new SVGMarkerElement(src, parent);
 				else if(name.endsWith(SVGElements.SVG_TEXT))
 					return new SVGTextElement(src, parent);
+				else if(name.endsWith(SVGElements.SVG_IMAGE))
+					return new SVGImageElement(src, parent);
 			}
 			else
 				return new OtherNSElement(src, parent);
