@@ -3,7 +3,6 @@ package latexDraw.parsers.svg.elements;
 import java.awt.Color;
 import java.text.ParseException;
 
-import latexDraw.figures.Figure;
 import latexDraw.parsers.svg.*;
 import latexDraw.parsers.svg.parsers.CSSStyleParser;
 import latexDraw.parsers.svg.parsers.SVGLengthParser;
@@ -263,48 +262,6 @@ public abstract class SVGElement implements Element, Cloneable
 
 
 	
-	protected void setGeneralAttributes(SVGNamedNodeMap attr, Figure f)
-	{
-		if(f==null || attr==null)
-			return ;
-		
-		Node node;
-		
-		if(f.isThicknessable())
-		{
-			node = attr.getNamedItem(SVGAttributes.SVG_STROKE_WIDTH);
-		
-			if(node!=null)
-				f.setThickness(Double.valueOf(node.getNodeValue()).floatValue());
-		}
-		
-		node = attr.getNamedItem(SVGAttributes.SVG_STROKE);
-		
-		if(node!=null)
-		{
-			Color c = CSSColors.getRGBColour(node.getNodeValue());
-		
-			if(c!=null)
-				f.setLinesColor(c);
-		}
-		
-		if(f.canBeFilled())
-		{
-			node = attr.getNamedItem(SVGAttributes.SVG_FILL);
-			
-			if(node!=null)
-			{
-				f.setIsFilled(true);
-				Color c = CSSColors.getRGBColour(node.getNodeValue());
-				
-				if(c!=null)
-					f.setInteriorColor(c);
-			}
-		}
-	}
-
-
-
 	public String getNodeName()
 	{
 		return name;
@@ -968,15 +925,13 @@ public abstract class SVGElement implements Element, Cloneable
 	 */
 	public double getStrokeWidth()
 	{
-		String swStr = getAttribute(getUsablePrefix()+SVGAttributes.SVG_STROKE_WIDTH);
+		String swStr = getSVGAttribute(SVGAttributes.SVG_STROKE_WIDTH, getUsablePrefix());
 		double sw;
 		
-		try 
-		{ 
+		try { 
 			sw = swStr==null ? parent==null ? 1 : parent.getStrokeWidth() : 
 				new SVGLengthParser(swStr).parseLength().getValue();
-		}
-		catch(ParseException e){ sw = 1; }
+		} catch(ParseException e){ sw = 1; }
 		
 		return sw;
 	}
@@ -989,7 +944,7 @@ public abstract class SVGElement implements Element, Cloneable
 	 */
 	public String getStrokeDasharray()
 	{
-		String da = getAttribute(getUsablePrefix()+SVGAttributes.SVG_STROKE_DASHARRAY);
+		String da = getSVGAttribute(SVGAttributes.SVG_STROKE_DASHARRAY, getUsablePrefix());
 		
 		return da==null ? parent==null ? SVGAttributes.SVG_VALUE_NONE : parent.getStrokeDasharray() : da;
 	}
@@ -1002,7 +957,7 @@ public abstract class SVGElement implements Element, Cloneable
 	 */
 	public String getLinecap()
 	{
-		String linecap = getAttribute(getUsablePrefix()+SVGAttributes.SVG_STROKE_LINECAP);
+		String linecap = getSVGAttribute(SVGAttributes.SVG_STROKE_LINECAP, getUsablePrefix());
 
 		return linecap==null ? parent==null ? SVGAttributes.SVG_LINECAP_VALUE_BUTT : parent.getLinecap() : linecap;
 	}
@@ -1028,7 +983,7 @@ public abstract class SVGElement implements Element, Cloneable
 	 */
 	public String getFill()
 	{
-		String fill = getAttribute(getUsablePrefix()+SVGAttributes.SVG_FILL);
+		String fill = getSVGAttribute(SVGAttributes.SVG_FILL, getUsablePrefix());
 		
 		return fill==null ? parent==null ? CSSColors.CSS_BLACK_NAME : parent.getFill() : fill;
 	}
@@ -1038,7 +993,7 @@ public abstract class SVGElement implements Element, Cloneable
 	 * @return The font-size value in point of the element, or from one of its parents.
 	 */
 	public float getFontSize() {
-		String fs = getAttribute(getUsablePrefix()+SVGAttributes.SVG_FONT_SIZE);
+		String fs = getSVGAttribute(SVGAttributes.SVG_FONT_SIZE, getUsablePrefix());
 		
 		return fs==null ? parent==null ? SVGLengthParser.FontSize.MEDIUM.getPointValue() : 
 					parent.getFontSize() : SVGLengthParser.fontSizetoPoint(fs);
@@ -1049,7 +1004,7 @@ public abstract class SVGElement implements Element, Cloneable
 	 * @return The defined or inherited font family. Otherwise, an empty string.
 	 */
 	public String getFontFamily() {
-		String fam = getAttribute(getUsablePrefix()+SVGAttributes.SVG_FONT_FAMILY);
+		String fam = getSVGAttribute(SVGAttributes.SVG_FONT_FAMILY, getUsablePrefix());
 		
 		return fam==null ? parent==null ? "" : parent.getFontFamily() : fam;
 	}
@@ -1059,7 +1014,7 @@ public abstract class SVGElement implements Element, Cloneable
 	 * @return The defined or inherited font style. Otherwise, the default value "normal" is returned.
 	 */
 	public String getFontStyle() {
-		String style = getAttribute(getUsablePrefix()+SVGAttributes.SVG_FONT_STYLE);
+		String style = getSVGAttribute(SVGAttributes.SVG_FONT_STYLE, getUsablePrefix());
 		
 		return style==null ? parent==null ? SVGAttributes.SVG_FONT_STYLE_NORMAL : parent.getFontStyle() : style;
 	}
@@ -1069,7 +1024,7 @@ public abstract class SVGElement implements Element, Cloneable
 	 * @return The defined or inherited font weight. Otherwise, the default value "normal" is returned.
 	 */
 	public String getFontWeight() {
-		String weight = getAttribute(getUsablePrefix()+SVGAttributes.SVG_FONT_WEIGHT);
+		String weight = getSVGAttribute(SVGAttributes.SVG_FONT_WEIGHT, getUsablePrefix());
 		
 		return weight==null ? parent==null ? SVGAttributes.SVG_FONT_WEIGHT_NORMAL : parent.getFontWeight() : weight;
 	}
@@ -1095,9 +1050,9 @@ public abstract class SVGElement implements Element, Cloneable
 	 */
 	public Color getStroke()
 	{
-		Node n = getAttributeNode(getUsablePrefix()+SVGAttributes.SVG_STROKE);
+		String stroke = getSVGAttribute(SVGAttributes.SVG_STROKE, getUsablePrefix());
 		
-		return n==null ? parent==null ? null : parent.getStroke() : CSSColors.getRGBColour(n.getNodeValue());
+		return stroke==null ? parent==null ? null : parent.getStroke() : CSSColors.getRGBColour(stroke);
 	}
 	
 	
@@ -1194,4 +1149,28 @@ public abstract class SVGElement implements Element, Cloneable
 	{
 		return stylesCSS;
 	}
+	
+	
+	
+	
+	/**
+	 * An SVG attribute can be defined in: its corresponding attribute (e.g. fill="...");
+	 * the attribute style (e.g. style="fill:...;..."); a CSS stylesheet. This function
+	 * returns the value of an SVG attribute by testing: 1. Its corresponding attribute;
+	 * 2. The attribute style is 1. fails. TODO CSS stylesheet are not managed yet.
+	 * @param attrName The name of the researched attribute.
+	 * @param prefix The usable prefix.
+	 * @return The found value or null.
+	 * @since 2.0.6
+	 */
+	public String getSVGAttribute(String attrName, String prefix) {
+		if(attrName==null) return null;
+		
+		String value = getAttribute((prefix==null?"":prefix) + attrName);
+		
+		if(value==null && stylesCSS!=null)
+			value = stylesCSS.get(attrName);
+		
+		return value;
+	}
 }
