@@ -1,5 +1,7 @@
 package latexDraw.parsers.svg.elements;
 
+import java.text.ParseException;
+
 import latexDraw.parsers.svg.MalformedSVGDocument;
 import latexDraw.parsers.svg.SVGDocument;
 import latexDraw.parsers.svg.SVGElements;
@@ -29,7 +31,7 @@ import org.w3c.dom.Node;
 public class SVGPolyLineElement extends AbstractPointsElement
 {
 
-	public SVGPolyLineElement(Node n, SVGElement p) throws MalformedSVGDocument
+	public SVGPolyLineElement(Node n, SVGElement p) throws MalformedSVGDocument, ParseException
 	{
 		super(n, p);
 	}
