@@ -1068,7 +1068,7 @@ public final class DrawContainer extends JComponent implements Scrollable, Print
 			return null;
 		}
 		
-		File texFile    = createLatexFile(name + TeXFilter.TEX_EXTENSION);
+		File texFile    = createLatexFile(tmpDir2 + sep + name + TeXFilter.TEX_EXTENSION);
 		String log;
 		File finalPS;
 		LaTeXDrawPoint2D nw = bordersComplete.getTheNWPoint(), se = bordersComplete.getTheSEPoint();
@@ -1083,7 +1083,7 @@ public final class DrawContainer extends JComponent implements Scrollable, Print
 		log    = execute(paramsLatex, tmpDir2);
 		File dviFile = new File(tmpDir2.getAbsolutePath() + sep + name + ".dvi");
 		boolean dviRenamed = dviFile.renameTo(new File(tmpDir2.getAbsolutePath() + sep + name));
-		String[] paramsDvi = new String[] {dirBin+"dvips", "-T", ((se.x-nw.x)/pixelsPerCm+dec)+"cm,"+((se.y-nw.y)/pixelsPerCm+dec)+"cm",
+		String[] paramsDvi = new String[] {dirBin+"dvips", "-Pdownload35", "-T", ((se.x-nw.x)/pixelsPerCm+dec)+"cm,"+((se.y-nw.y)/pixelsPerCm+dec)+"cm",
 											name, "-o", pathExportPs};
 		dirBin = dirBin==null ? "" : dirBin.endsWith(sep) || dirBin.length()==0 ? dirBin : dirBin + sep;
 		log   += execute(paramsDvi, tmpDir2);
@@ -1176,16 +1176,20 @@ public final class DrawContainer extends JComponent implements Scrollable, Print
 		if(psFile==null)
 			return null;
 
+		// On windows, an option must be defined using this format:
+		// -optionName#valueOption Thus, the classical = character must be replaced by a # when latexdraw runs on Windows.
+		String optionEmbed = "-dEmbedAllFonts" + (System.getProperty("os.name").toLowerCase().contains("win") ? "#" : "=") + "true";
+		
 		dirBin  = dirBin==null ? "" : dirBin.endsWith(sep) || dirBin.length()==0 ? dirBin : dirBin + sep;
-		log 	= execute(new String[] {dirBin + "ps2pdf", psFile.getAbsolutePath(), 
+		log 	= execute(new String[] {dirBin + "ps2pdf", optionEmbed, psFile.getAbsolutePath(), 
 							crop ? name + PDFFilter.PDF_EXTENSION : pathExportPdf}, tmpDir);
 		
 		if(crop) {
-			pdfFile = new File(latexDistribPath, tmpDir.getAbsolutePath() + sep + name + PDFFilter.PDF_EXTENSION);
+			pdfFile = new File(tmpDir.getAbsolutePath() + sep + name + PDFFilter.PDF_EXTENSION);
 			log 	= execute(new String[] {dirBin + "pdfcrop", pdfFile.getAbsolutePath(), pdfFile.getAbsolutePath()}, tmpDir);
 			if(!pdfFile.renameTo(new File(pathExportPdf)))// JAVA7: test pdfFile.toPath().move(pathExportPdf)
 				if(!LFileUtils.copy(pdfFile, new File(pathExportPdf)))// the renameto method is weak and fails sometimes.
-					log += " The final pdf document cannot be moved to its final destination.";
+					log += " The final pdf document cannot be moved to its final destination. If you use Windows, you must have a Perl interpretor installed, such as strawberryPerl (http://strawberryperl.com/)";
 			pdfFile.delete();
 		}
 		
@@ -2060,30 +2064,61 @@ public final class DrawContainer extends JComponent implements Scrollable, Print
 
 
 	/**
-	 * Allows to copy the selected figure
+	 * Copies the selected figures.
 	 */
-	public void copy() 
-	{
-		try
-		{
-			if(!selected.isEmpty())
-			{
-				copiedFigure = (Draw) selected.clone();
+	public void copy() {
+		copy(false);
+	}
+
+
+	
+	
+	protected void copy(boolean cut) {
+		try {
+			if(!selected.isEmpty()) {
+				final int size = selected.size();
+				int[] index = new int[size];
+				int i;
+				
+				copiedFigure = new Draw(false, false);
+				
+				for(i=0; i<size; i++)
+					index[i] = figures.indexOf(selected.getFigureAt(i));
+				
+				Arrays.sort(index);
+				
+				for(i=0; i<size; i++)
+					copiedFigure.addFigure((Figure) figures.get(index[i]).clone());
+
 				parentPanel.getFrameParent().setMenuPaste(true);
+				
+				if(cut) {
+					parentPanel.getFrameParent().getUndoManager().add(UndoRedoManager.LABEL_DEL, index, copiedFigure.clone(), false);
+					parentPanel.getFrameParent().updateUndoRedo();
+					
+					for(i=0; i<selected.size();)
+						deleteFigure(selected.getFigureAt(i), null);
+					
+					parentPanel.getFrameParent().setMenuCopy(false);
+					parentPanel.getFrameParent().setSelection(false);
+					parentPanel.getFrameParent().setExportAsMenu(!figures.isEmpty());
+					selected.clear();
+					parentPanel.updateDraw(true);
+					setIsModified(true);
+				}
 			}
 		}
-		catch(Exception e)
-		{
+		catch(Exception e) {
 			e.printStackTrace(); 
 			ExceptionFrameDialog.showExceptionDialog(e);
 		}
 	}
-
-
+	
+	
 
 
 	/**
-	 * Allows to paste a copied or a cut figure
+	 * Pastes copied or cut figures.
 	 */
 	public void paste()
 	{
@@ -2126,45 +2161,10 @@ public final class DrawContainer extends JComponent implements Scrollable, Print
 
 
 	/**
-	 * Allows to cut the selected figure
+	 * Cuts the selected figures.
 	 */
-	public void cut() 
-	{
-		try
-		{
-			if(selected!=null && !selected.isEmpty())
-			{		
-				copiedFigure = (Draw) selected.clone();
-				Draw cloneUndo = (Draw) selected.clone();
-				int[] id = new int[selected.size()];
-				
-				for(int i=0, size=selected.size(); i<size; i++)
-				{
-					id[i] = figures.indexOf(selected.getFigureAt(i));
-					if(id[i]<0)
-						throw new IndexOutOfBoundsException();
-				}
-
-				parentPanel.getFrameParent().getUndoManager().add(UndoRedoManager.LABEL_DEL, id, cloneUndo, false);
-				parentPanel.getFrameParent().updateUndoRedo();
-				
-				for(int i=0; i<selected.size();)
-					deleteFigure(selected.getFigureAt(i), null);
-				
-				parentPanel.getFrameParent().setMenuCopy(false);
-				parentPanel.getFrameParent().setSelection(false);
-				parentPanel.getFrameParent().setMenuPaste(true);
-				parentPanel.getFrameParent().setExportAsMenu(!figures.isEmpty());
-				selected.clear();
-				parentPanel.updateDraw(true);
-				setIsModified(true);
-			}
-		}
-		catch(Exception e)
-		{
-			e.printStackTrace();
-			ExceptionFrameDialog.showExceptionDialog(e);
-		}
+	public void cut() {
+		copy(true);
 	}
 	
 	
