@@ -16,11 +16,14 @@ import latexDraw.figures.properties.Arrowable;
 import latexDraw.lang.LaTeXDrawLang;
 import latexDraw.psTricks.PSTricksConstants;
 import latexDraw.ui.dialog.ExceptionFrameDialog;
-import latexDraw.util.*;
+import latexDraw.util.LaTeXDrawCursor;
+import latexDraw.util.LaTeXDrawNamespace;
+import latexDraw.util.LaTeXDrawPoint2D;
+import latexDraw.util.LaTeXDrawResources;
+import latexDraw.util.UndoRedoManager;
 
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
-import org.w3c.dom.Node;
 import org.w3c.dom.NodeList;
 
 /** 
@@ -514,28 +517,30 @@ public final class DrawPanel extends JScrollPane implements MouseListener, Mouse
 	
 	
 	/**
-	 * Allows to export the drawing as a jpeg file
-	 * @param file The new jpeg file
+	 * Exports the drawing as a picture.
+	 * @param file The new picture to create.
+	 * @param format The extension of the picture to create.
 	 * @param compressionRate The compression rate for jpg pictures.
 	 */
 	public void exportAsPicture(File file, String format, float compressionRate) 
 	{
 		if(format.equals(LaTeXDrawResources.LABEL_EXPORT_JPG))
 			  draw.exportAsJPG(file, compressionRate);
-		else
-		if(format.equals(LaTeXDrawResources.LABEL_EXPORT_EPS))	
+		else if(format.equals(LaTeXDrawResources.LABEL_EXPORT_EPS))	
 			draw.exportAsEPS(file);
-		else
-		if(format.equals(LaTeXDrawResources.LABEL_EXPORT_PNG))	
+		else if(format.equals(LaTeXDrawResources.LABEL_EXPORT_PNG))	
 			draw.exportAsPNG(file);
-		else
-		if(format.equals(LaTeXDrawResources.LABEL_EXPORT_BMP))	
+		else if(format.equals(LaTeXDrawResources.LABEL_EXPORT_BMP))	
 			draw.exportAsBMP(file);
-		else
-		if(format.equals(LaTeXDrawResources.LABEL_EXPORT_PPM))	
+		else if(format.equals(LaTeXDrawResources.LABEL_EXPORT_PPM))	
 			draw.exportAsPPMFile(file);
-		else
-			throw new IllegalArgumentException();
+		else if(format.equals(LaTeXDrawResources.LABEL_EXPORT_PDF_LATEX))
+			draw.createPDFFile(frameParent.getPathDistribLatex(), file.getPath(), false);
+		else if(format.equals(LaTeXDrawResources.LABEL_EXPORT_PDF_LATEX_CROP))
+			draw.createPDFFile(frameParent.getPathDistribLatex(), file.getPath(), true);
+		else if(format.equals(LaTeXDrawResources.LABEL_EXPORT_EPS_LATEX))	
+			draw.createPSFile(frameParent.getPathDistribLatex(), file.getPath());
+		else throw new IllegalArgumentException(format);
 	}
 	
 		
@@ -1380,6 +1385,7 @@ public final class DrawPanel extends JScrollPane implements MouseListener, Mouse
 			DrawBorders db = draw.getCompleteBorders();
 			if(db!=null && db.isSelected() && db.isADelimitorSelected())
 			{
+				setIsModified(true);
 				db.onDelimitorRelease();
 				return ;
 			}
@@ -2001,30 +2007,8 @@ public final class DrawPanel extends JScrollPane implements MouseListener, Mouse
 	 * @param nl The list of the parameters.
 	 * @since 2.0.0
 	 */
-	public void setXMLMetadata(NodeList nl)
-	{
-		if(nl==null)
-			return ;
-		
-		Node n;
-		String name;
-		
-		for(int i=0, size = nl.getLength(); i<size; i++)
-		{
-			n = nl.item(i);
-			
-			if(n!=null && LaTeXDrawNamespace.LATEXDRAW_NAMESPACE_URI.equals(n.getNamespaceURI()))
-			{
-				name = n.getNodeName();
-				
-				try
-				{
-					if(name.endsWith(LaTeXDrawNamespace.XML_MAGNETIC_GRID))
-						setGridIsMagnetic(Boolean.valueOf(n.getTextContent()).booleanValue());
-				}
-				catch(Exception e) { System.out.println(name + ": invalid value."); }//$NON-NLS-1$
-			}
-		}
+	public void setXMLMetadata(NodeList nl) {
+		// Nothing to do.
 	}
 
 
