@@ -316,6 +316,21 @@ public class LMenuBar extends JMenuBar
         menu.setActionCommand(LaTeXDrawResources.LABEL_EXPORT_PPM);
         exportAsMenu.add(menu);
         
+        menu = new JMenuItem("eps (latex) picture", KeyEvent.VK_S);
+        menu.addActionListener(ml); 
+        menu.setActionCommand(LaTeXDrawResources.LABEL_EXPORT_EPS_LATEX);
+        exportAsMenu.add(menu);
+        
+        menu = new JMenuItem("pdf (latex) picture", KeyEvent.VK_F);
+        menu.addActionListener(ml); 
+        menu.setActionCommand(LaTeXDrawResources.LABEL_EXPORT_PDF_LATEX);
+        exportAsMenu.add(menu);
+        
+        menu = new JMenuItem("pdf (latex+pdfcrop) picture", KeyEvent.VK_C);
+        menu.addActionListener(ml); 
+        menu.setActionCommand(LaTeXDrawResources.LABEL_EXPORT_PDF_LATEX_CROP);
+        exportAsMenu.add(menu);
+        
         exportTemplateMenu = new JMenuItem(LaTeXDrawResources.LABEL_TEMPLATE_EXPORT);
         exportTemplateMenu.addActionListener(ml); 
         exportTemplateMenu.setActionCommand(LaTeXDrawResources.LABEL_TEMPLATE_EXPORT);
