@@ -73,6 +73,7 @@ public class LToolbar extends JToolBar
 	protected JButton buttonImageRedo;
 	protected JButton buttonImageUndo;
 	protected LaTeXDrawFrame parentFrame;
+	protected JButton buttonPdfExport;
 	
 	
 	
@@ -110,6 +111,14 @@ public class LToolbar extends JToolBar
  		button.setToolTipText(LaTeXDrawLang.getStringLaTeXDrawFrame("LaTeXDrawFrame.110")); //$NON-NLS-1$
  		button.setActionCommand(LaTeXDrawResources.LABEL_SAVE);
  		add(button);
+ 		
+ 		buttonPdfExport = new JButton(LaTeXDrawResources.pdfIcon);		
+ 		buttonPdfExport.addActionListener(ml);
+ 		buttonPdfExport.setEnabled(false);
+ 		buttonPdfExport.setMargin(LaTeXDrawFrame.INSET_BUTTON);
+ 		buttonPdfExport.setToolTipText("Export the drawing as a pdf document (the drawing is compiled using your latex distribution)");
+ 		buttonPdfExport.setActionCommand(LaTeXDrawResources.LABEL_EXPORT_PDF_LATEX);
+ 		add(buttonPdfExport);
 
  		addSeparator();
  		
@@ -760,4 +769,9 @@ public class LToolbar extends JToolBar
 	{
 		return zoomField;
 	}
+
+
+	public JButton getButtonPdfExport() {
+		return buttonPdfExport;
+	}
 }
