@@ -386,11 +386,7 @@ public class BatchConvertFrame extends JFrame implements ActionListener, ListSel
 			 		picturesChooser.setAcceptAllFileFilterUsed(false);
 			  		recursiveCB = new JCheckBox(LABEL_RECURSIVE);
 			  		recursiveCB.setSelected(false);
-			  		JPanel custom = new JPanel(); 
-			 		custom.setLayout(new BoxLayout(custom, BoxLayout.Y_AXIS)); 
-			 		custom.add(recursiveCB); 
-			 		picturesChooser.add(custom, BorderLayout.SOUTH);
-			  		
+			 		picturesChooser.setAccessory(recursiveCB);
 					picturesChooser.setCurrentDirectory(new File(LaTeXDrawFrame.getPathOpen()));
 			  		picturesChooser.setApproveButtonText(LaTeXDrawLang.getStringLaTeXDrawFrame("LaTeXDrawFrame.171")); //$NON-NLS-1$
 			  		picturesChooser.setDialogTitle(LaTeXDrawLang.getString1_6("BatchConvertFrame.13"));     //$NON-NLS-1$
