@@ -524,19 +524,34 @@ public class MenusListener extends AbstractListener implements ActionListener
     		{
     			mainFrame.batchConvertion();
     			return;
-    		}   
+    		}
     		
     		if(label.equals(LaTeXDrawResources.LABEL_EXPORT_TRICKS))
     		{
     			mainFrame.exportAsPsTricks();
     			return;
-    		}    		
+    		}	
+    		
+    		if(label.equals(LaTeXDrawResources.LABEL_EXPORT_PDF_LATEX_CROP)) {
+    			mainFrame.exportAsPicture(LaTeXDrawResources.LABEL_EXPORT_PDF_LATEX_CROP);
+    			return;
+    		}
+    		
+    		if(label.equals(LaTeXDrawResources.LABEL_EXPORT_PDF_LATEX)) {
+    			mainFrame.exportAsPicture(LaTeXDrawResources.LABEL_EXPORT_PDF_LATEX);
+    			return;
+    		}
+    		
+    		if(label.equals(LaTeXDrawResources.LABEL_EXPORT_EPS_LATEX)) {
+    			mainFrame.exportAsPicture(LaTeXDrawResources.LABEL_EXPORT_EPS_LATEX);
+    			return;
+    		}
     		
     		if(label.equals(LaTeXDrawResources.LABEL_EXPORT_BMP))
     		{
     			mainFrame.exportAsPicture(LaTeXDrawResources.LABEL_EXPORT_BMP);
     			return;
-    		}  
+    		}
     		
     		if(label.equals(LaTeXDrawResources.LABEL_EXPORT_JPG))
     		{
