@@ -98,6 +98,12 @@ public abstract class LaTeXDrawResources
     /** The beginning of the action command of templates */
     public static final String TEMPLATE_START_ACTION_CMD = "template_";//$NON-NLS-1$
     
+    public final static String LABEL_EXPORT_EPS_LATEX = "EPS_LATEX_EXPORT";//$NON-NLS-1$
+    
+    public final static String LABEL_EXPORT_PDF_LATEX = "PDF_LATEX_EXPORT";//$NON-NLS-1$
+    
+    public final static String LABEL_EXPORT_PDF_LATEX_CROP = "PDFCROP_LATEX_EXPORT";//$NON-NLS-1$
+    	
     /** The name of the extension of GIF file */
 	public static final String GIF_EXTENSION = ".gif";//$NON-NLS-1$
 	
@@ -347,6 +353,7 @@ public abstract class LaTeXDrawResources
 	
 	public static final String NAME_SLIDER_DELIMITOR = "sliderDel";//$NON-NLS-1$
 	
+	public final static ImageIcon pdfIcon ;
 	public final static ImageIcon bezierCurveIcon; 			public final static ImageIcon chordIcon;
 	public final static ImageIcon newIcon;					public final static ImageIcon lineStyleNoneIcon;
 	public final static ImageIcon openIcon; 				public final static ImageIcon lineStyleDashedIcon;
@@ -566,6 +573,7 @@ public abstract class LaTeXDrawResources
 		updateIcon			= loadImageIcon("/res/system-software-update.png"); //$NON-NLS-1$
 		drawingPropIcon		= loadImageIcon("/res/document-properties.png"); //$NON-NLS-1$
 		latexdrawIcon		= loadImageIcon("/res/LaTeXDrawIcon.png"); //$NON-NLS-1$
+		pdfIcon				= loadImageIcon("/res/pdf.png"); //$NON-NLS-1$
 		
 		alignBottomIcon		= loadImageIcon("/res/align/alignBottom.png"); //$NON-NLS-1$
 		alignLeftIcon		= loadImageIcon("/res/align/alignLeft.png"); //$NON-NLS-1$
